(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 14.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    177448,       3776]
NotebookOptionsPosition[    170220,       3636]
NotebookOutlinePosition[    170893,       3657]
CellTagsIndexPosition[    170850,       3654]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Linear Stability analysis of RMI", "Title",
 CellChangeTimes->{{3.91447030948783*^9, 3.9144703259444103`*^9}, {
  3.914488863831675*^9, 3.914488867775477*^9}, {3.9216469548213053`*^9, 
  3.9216469602759733`*^9}, {3.93330955447096*^9, 
  3.9333095691734257`*^9}},ExpressionUUID->"221d62ef-f87e-4ae8-ae59-\
271d3a76b034"],

Cell[CellGroupData[{

Cell[TextData[{
 "M. Napieralski, F. Cobos, A. L. Velikovich, and C. ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Huete", "1"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "a663ccbc-9f43-4ff0-8ce2-80f9229d89a6"]
}], "Subsubsection",
 CellChangeTimes->{{3.936326103375948*^9, 3.936326131066393*^9}, {
  3.936326279516054*^9, 
  3.936326282442533*^9}},ExpressionUUID->"07f27839-b6a7-4ccb-addd-\
a8339160cab7"],

Cell[TextData[{
 "This  notebook can be used to solve the linear stability analysis of the \
Ricthmyer Meshkov instability for an arbitrary equation of state (EoS). \nThe \
output from run this code is the temporal evolution of the growth rate and \
its asymptotic value. \nThe authors aim to cite the work when the code is \
used, and also contact to the correspondence ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["author", "1"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "5bb77cab-240a-4211-9ecd-a91c9b8fbbea"],
 " : chute@ing.uc3m.es. \n\nAnother thing to highlight is that this notebook \
follows mostly the same notation that one used in the manuscript, when some \
variable is named in a different form that in the main text is properly \
commented. "
}], "Text",
 CellChangeTimes->{{3.933309571542548*^9, 3.933309635429832*^9}, {
  3.936326175092874*^9, 3.9363263450320997`*^9}, {3.9363265908521643`*^9, 
  3.9363266957214413`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"80a5e2fd-be1f-4b38-81b2-c7c51ec9f6dc"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notebook configuration", "Chapter",
 CellChangeTimes->{{3.933309722299868*^9, 
  3.933309737256777*^9}},ExpressionUUID->"9742315d-542b-4839-ba5c-\
3c7a550c1644"],

Cell[CellGroupData[{

Cell["Numerical settings", "Section",
 CellChangeTimes->{{3.933309625799654*^9, 3.933309633050187*^9}, {
  3.936326079743042*^9, 
  3.9363260830849457`*^9}},ExpressionUUID->"49dd84d4-d6e0-4e41-b11f-\
74ae5bc397bb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Clear", " ", "all", " ", "the", " ", "variables"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zero", ":=", 
   SuperscriptBox["10", 
    RowBox[{"-", "8"}]]}], " ", 
  RowBox[{"(*", 
   RowBox[{"Numerical", " ", "zero"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"prec", ":=", " ", "10", " ", 
  RowBox[{"(*", 
   RowBox[{"Numerical", " ", "precision"}], "*)"}]}]}], "Input",
 CellChangeTimes->{{3.933309646240698*^9, 3.933309656985533*^9}, {
  3.936326368463706*^9, 3.936326378983204*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[1]:=",ExpressionUUID->"60912529-a365-43a2-827d-86bb52c5839a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot settings", "Section",
 CellChangeTimes->{{3.89830698727073*^9, 3.8983069977500143`*^9}, {
  3.9333096807743893`*^9, 
  3.933309689476254*^9}},ExpressionUUID->"06afa9a3-3d35-444e-afb0-\
03735e33380e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "ParametricPlot", ",", "Plot", ",", "ListCurvePathPlot", ",", "ListPlot",
       ",", "ListLogPlot", ",", "LogPlot", ",", "ListLogLogPlot", ",", 
      "LogLinearPlot", ",", "ListLinePlot", ",", "LogLogPlot", ",", 
      "ContourPlot", ",", "DensityPlot"}], "}"}], ",", 
    RowBox[{"BaseStyle", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", "->", "\"\<CMU Serif\>\""}], ",", 
       RowBox[{"FontSlant", "->", "Plain"}], ",", 
       RowBox[{"FontSize", "->", "20"}]}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "->", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "->", "\"\<CMU Serif\>\""}], ",", 
       RowBox[{"FontSlant", "->", "Plain"}], ",", 
       RowBox[{"FontSize", "->", "18"}], ",", 
       RowBox[{"RGBColor", "[", 
        RowBox[{"0", ",", "0", ",", "0"}], "]"}]}], "]"}]}], ",", 
    RowBox[{"Frame", "->", "False"}], ",", 
    RowBox[{"RotateLabel", "->", "False"}], ",", 
    RowBox[{"ImageSize", "->", "Large"}], ",", 
    RowBox[{"AspectRatio", "->", 
     RowBox[{"1", "/", "2"}]}], ",", 
    RowBox[{"Axes", "->", "True"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.911467969913903*^9, 3.911468071339466*^9}, {
  3.914242072074814*^9, 3.914242077806713*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"e343ac79-5969-4d47-beae-261f8151f9b9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"myblue", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     FractionBox["20", "255"], ",", 
     FractionBox["150", "255"], ",", 
     FractionBox["220", "255"]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"myorange", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     FractionBox["240", "255"], ",", 
     FractionBox["153", "255"], ",", 
     FractionBox["54", "255"]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mygreen", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     FractionBox["82", "255"], ",", 
     FractionBox["200", "255"], ",", 
     FractionBox["54", "255"]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"myred", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     FractionBox["220", "255"], ",", 
     FractionBox["70", "255"], ",", 
     FractionBox["80", "255"]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mygray", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     FractionBox["145", "255"], ",", 
     FractionBox["145", "255"], ",", 
     FractionBox["145", "255"]}], "]"}]}], ";"}]}], "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"2b20ab53-041e-4d5e-928f-4a2aac05fe87"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Perturbation physical parameters", "Chapter",
 CellChangeTimes->{{3.925357923844552*^9, 3.925357929643735*^9}, {
  3.925961635002481*^9, 3.925961647053279*^9}, {3.933309742608436*^9, 
  3.933309760705099*^9}},ExpressionUUID->"0db2606d-ede3-4caa-be17-\
c224a0f8bb8f"],

Cell[BoxData[{
 RowBox[{"Mi", ":=", "1.5"}], "\[IndentingNewLine]", 
 RowBox[{"Ri", ":=", "1.3585729194103697`"}], "\[IndentingNewLine]", 
 RowBox[{"Rt", ":=", "1.4224705394740176`"}], "\[IndentingNewLine]", 
 RowBox[{"Rr", ":=", "1.079788171388501`"}], "\[IndentingNewLine]", 
 RowBox[{"Mt", " ", ":=", "1.8106059988362586`"}], "\[IndentingNewLine]", 
 RowBox[{"Mr", ":=", "1.0823609481311853`"}], "\[IndentingNewLine]", 
 RowBox[{"M2t", ":=", "0.7028820640032412`"}], "\[IndentingNewLine]", 
 RowBox[{"M2r", ":=", "0.9285340439519515`"}], "\[IndentingNewLine]", 
 RowBox[{"ht", ":=", 
  RowBox[{"-", "0.3941993660815628`"}]}], "\[IndentingNewLine]", 
 RowBox[{"hr", ":=", 
  RowBox[{"-", "0.856115705509378`"}]}], "\[IndentingNewLine]", 
 RowBox[{"Pt", ":=", "58.309617669619136`"}], "\[IndentingNewLine]", 
 RowBox[{"Pr", ":=", "1.4179774131000236`"}], "\[IndentingNewLine]", 
 RowBox[{"\[Xi]t0", ":=", "0.3753700156640911`"}], "\[IndentingNewLine]", 
 RowBox[{"\[Xi]r0", ":=", "1.7973419072713024`"}], "\[IndentingNewLine]", 
 RowBox[{"\[Xi]i0", ":=", "0.8144863045447566`"}], "\[IndentingNewLine]", 
 RowBox[{"\[Kappa]2t", ":=", "4.708970455156653`"}], "\[IndentingNewLine]", 
 RowBox[{"\[Kappa]2r", ":=", "4.284985197412184`"}], "\[IndentingNewLine]", 
 RowBox[{"\[Theta]", ":=", "0.9099622174778832`"}], "\[IndentingNewLine]", 
 RowBox[{"\[Beta]", ":=", "1.694316816743171`"}], "\[IndentingNewLine]", 
 RowBox[{"SWparameter", ":=", 
  "3.1547635070376505`"}], "\[IndentingNewLine]", 
 RowBox[{"At", ":=", "0.5297942156246976`"}], "\[IndentingNewLine]"}], "Input",\

 CellChangeTimes->{{3.925961811421918*^9, 3.925961929940916*^9}, {
   3.925961976842012*^9, 3.925962578047769*^9}, {3.933309768955833*^9, 
   3.933309921103645*^9}, 3.933311557726581*^9, 3.933312036376171*^9, {
   3.936326417621369*^9, 3.936326418042729*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[10]:=",ExpressionUUID->"0a0c2f1b-1bb4-4b0a-b653-2e0ee9417ae8"]
}, Closed]],

Cell[CellGroupData[{

Cell["Functional system resolution", "Chapter",
 CellChangeTimes->{{3.904736406997789*^9, 3.904736412413943*^9}, {
  3.925529934407715*^9, 3.925529934837707*^9}, {3.925962638589418*^9, 
  3.925962650703012*^9}, {3.9333128674769707`*^9, 
  3.933312877558683*^9}},ExpressionUUID->"bd933514-24a4-469a-aaf0-\
60fec6af7039"],

Cell[CellGroupData[{

Cell["Rankine Hugoniot Coefficients", "Subsection",
 CellChangeTimes->{{3.904735477532476*^9, 3.904735496060032*^9}, {
   3.936326516334833*^9, 3.936326549991987*^9}, 
   3.9363265801860867`*^9},ExpressionUUID->"888fd9c8-eca0-406b-9e43-\
d7ab9d92af75"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Sigma]1", "[", 
   RowBox[{"M2_", ",", "R_", ",", "h_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"1", "+", "h"}], 
    RowBox[{"2", " ", 
     SuperscriptBox["M2", "2"]}]], " ", 
   FractionBox["R", 
    RowBox[{"R", "-", "1"}]], 
   FractionBox["M2", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["M2", "2"]}]]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]2", "[", 
   RowBox[{"M2_", ",", "R_", ",", "h_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"1", "-", "h"}], 
   RowBox[{"2", " ", "M2"}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]3", "[", 
   RowBox[{"M2_", ",", "R_", ",", "h_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"M2", "^", "2"}], 
    RowBox[{"(", 
     RowBox[{"R", "-", "1"}], ")"}]}], 
   RowBox[{"Sqrt", "[", 
    RowBox[{"1", "-", 
     SuperscriptBox["M2", "2"]}], "]"}]]}]}], "Input",
 CellChangeTimes->{{3.904735501423074*^9, 3.904735555309857*^9}, {
  3.904735600542188*^9, 3.904735676755748*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[32]:=",ExpressionUUID->"b35602b7-c0c9-4e1d-8be5-b6ebb272471f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Shifts respect to the shock SetUp", "Subsection",
 CellChangeTimes->{{3.904736421837617*^9, 3.9047364285092907`*^9}, {
  3.904736516070006*^9, 3.904736535822153*^9}, {3.936326535172206*^9, 
  3.936326544240035*^9}},ExpressionUUID->"0d3bdf72-4a6f-40d6-818c-\
2af93e9f5e38"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Chi]ts", ":=", 
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{"ArcTanh", "[", "M2t", "]"}], ",", "prec"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Chi]rs", ":=", " ", 
  RowBox[{"-", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"ArcTanh", "[", "M2r", "]"}], ",", "prec"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<The frequency shift with respect the transmitted shock front is: \>\"",
    ",", "\[Chi]ts"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<The frequency shift with respect the reflected shock front is: \>\"", 
   ",", "\[Chi]rs"}], "]"}]}], "Input",
 CellChangeTimes->{{3.904736439087882*^9, 3.904736467829955*^9}, 
   3.904793841459914*^9, {3.908453432626032*^9, 3.908453438087257*^9}, {
   3.925962750044194*^9, 3.925962751654004*^9}, {3.933311299024597*^9, 
   3.9333113003041697`*^9}, {3.936326437347003*^9, 3.9363265053016233`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[35]:=",ExpressionUUID->"a2ff33b0-bf45-4a4d-8db4-06109cda43c8"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The frequency shift with respect the transmitted shock front \
is: \"\>", "\[InvisibleSpace]", "0.8729741377385093`"}],
  SequenceForm[
  "The frequency shift with respect the transmitted shock front is: ", 
   0.8729741377385093],
  Editable->False]], "Print",
 CellChangeTimes->{3.936326746678854*^9},
 CellLabel->
  "During evaluation of \
In[35]:=",ExpressionUUID->"a57868f2-0469-4c56-bff5-b996bf49deed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The frequency shift with respect the reflected shock front is: \
\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "1.6476471167221225`"}]}],
  SequenceForm[
  "The frequency shift with respect the reflected shock front is: ", \
-1.6476471167221225`],
  Editable->False]], "Print",
 CellChangeTimes->{3.936326746679673*^9},
 CellLabel->
  "During evaluation of \
In[35]:=",ExpressionUUID->"a9098e5b-22d2-42ad-90df-473486bb4951"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Changes of variables auxiliary functions", "Subsection",
 CellChangeTimes->{{3.904736628341649*^9, 
  3.904736640470208*^9}},ExpressionUUID->"e1b7db39-2fab-482c-a2ff-\
71edb0439947"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Zeta]t", "[", "qr_", "]"}], ":=", 
  RowBox[{"ArcSinh", "[", 
   RowBox[{
    RowBox[{"Sinh", "[", "qr", "]"}], "\[Beta]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Zeta]r", "[", "qt_", "]"}], ":=", 
  RowBox[{"ArcSinh", "[", 
   FractionBox[
    RowBox[{"Sinh", "[", "qt", "]"}], "\[Beta]"], "]"}]}]}], "Input",
 CellChangeTimes->{{3.904736644640321*^9, 3.904736738692543*^9}, {
  3.904793784548641*^9, 3.904793793334945*^9}, {3.904793828061945*^9, 
  3.904793833493319*^9}, {3.9259627691758823`*^9, 3.92596277323741*^9}, {
  3.933311308423605*^9, 3.933311313314908*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[40]:=",ExpressionUUID->"21cbd1bd-fdc8-44ed-aff7-25084835dd53"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Functions (A12)-(A13) for the transmitted and reflected shock fronts\
\>", "Subsection",
 CellChangeTimes->{{3.904737014199274*^9, 3.904737028215375*^9}, 
   3.904737513173912*^9, {3.904737696693316*^9, 3.90473770481324*^9}, {
   3.925399639388773*^9, 3.925399643731649*^9}, 3.933312900808857*^9, {
   3.936326874564472*^9, 3.9363269016745157`*^9}, {3.9363269386096973`*^9, 
   3.936326954661891*^9}},ExpressionUUID->"c2ffdcb2-95b1-498e-8b0d-\
efa40dd5fd64"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.936326921114305*^9, 
  3.936326965585021*^9}},ExpressionUUID->"f61df6af-e350-4c16-87ba-\
da5934f8ac4d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Transmitted", " ", 
    RowBox[{"front", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]t", "[", "qt_", "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{"Sinh", "[", "qt", "]"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Sinh", "[", "qt", "]"}], 
        RowBox[{"Cosh", "[", "qt", "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Sigma]2", "[", 
         RowBox[{"M2t", ",", "Rt", ",", "ht"}], "]"}], 
        SuperscriptBox[
         RowBox[{"Sinh", "[", "qt", "]"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"\[Sigma]1", "[", 
         RowBox[{"M2t", ",", "Rt", ",", "ht"}], "]"}], 
        RowBox[{"\[Sigma]3", "[", 
         RowBox[{"M2t", ",", "Rt", ",", "ht"}], "]"}]}]}], ")"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Ptsiso", "[", "qt_", "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]3", "[", 
        RowBox[{"M2t", ",", "Rt", ",", "ht"}], "]"}], "\[Xi]t0"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Sinh", "[", "qt", "]"}], 
        RowBox[{"Cosh", "[", "qt", "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Sigma]2", "[", 
         RowBox[{"M2t", ",", "Rt", ",", "ht"}], " ", "]"}], 
        SuperscriptBox[
         RowBox[{"Sinh", "[", "qt", "]"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"\[Sigma]1", "[", 
         RowBox[{"M2t", ",", "Rt", ",", "ht"}], "]"}], 
        RowBox[{"\[Sigma]3", "[", 
         RowBox[{"M2t", ",", "Rt", ",", "ht"}], "]"}]}]}], ")"}]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", 
           RowBox[{"--", 
            RowBox[{"--", 
             RowBox[{"--", 
              RowBox[{"--", 
               RowBox[{"--", 
                RowBox[{"--", 
                 RowBox[{"--", 
                  RowBox[{"--", 
                   RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{
                    "--", "--"}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}], 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Reflected", " ", 
     RowBox[{"front", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Alpha]r", "[", "qr_", "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{"Sinh", "[", "qr", "]"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Sinh", "[", "qr", "]"}], 
        RowBox[{"Cosh", "[", "qr", "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Sigma]2", "[", 
         RowBox[{"M2r", ",", "Rr", ",", "hr"}], "]"}], 
        SuperscriptBox[
         RowBox[{"Sinh", "[", "qr", "]"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"\[Sigma]1", "[", 
         RowBox[{"M2r", ",", "Rr", ",", "hr"}], "]"}], 
        RowBox[{"\[Sigma]3", "[", 
         RowBox[{"M2r", ",", "Rr", ",", "hr"}], "]"}]}]}], ")"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Prsiso", "[", "qr_", "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]3", "[", 
        RowBox[{"M2r", ",", "Rr", ",", "hr"}], "]"}], "\[Xi]r0"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Sinh", "[", "qr", "]"}], 
        RowBox[{"Cosh", "[", "qr", "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Sigma]2", "[", 
         RowBox[{"M2r", ",", "Rr", ",", "hr"}], "]"}], 
        SuperscriptBox[
         RowBox[{"Sinh", "[", "qr", "]"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"\[Sigma]1", "[", 
         RowBox[{"M2r", ",", "Rr", ",", "hr"}], "]"}], 
        RowBox[{"\[Sigma]3", "[", 
         RowBox[{"M2r", ",", "Rr", ",", "hr"}], "]"}]}]}], 
      ")"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.9253994368499203`*^9, 3.925399545768452*^9}, {
  3.925463388535094*^9, 3.925463403540948*^9}, {3.925962655743361*^9, 
  3.9259626771769958`*^9}, {3.933311318444815*^9, 3.933311349665149*^9}, {
  3.936326967630474*^9, 3.936327042117097*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[42]:=",ExpressionUUID->"e91fc9b1-1761-41df-bfc3-46afda2d0946"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coefficients for the iteration scheme relation", "Subsection",
 CellChangeTimes->{{3.904211738018664*^9, 3.90421175258606*^9}, {
  3.908600837195796*^9, 
  3.908600844067089*^9}},ExpressionUUID->"29f276de-42ab-46b2-90fe-\
29c6700d19bf"],

Cell[CellGroupData[{

Cell["Auxiliary functions (A15)", "Subsubsection",
 CellChangeTimes->{{3.902998355392528*^9, 3.902998360238472*^9}, {
  3.9363271497894573`*^9, 
  3.9363271638823357`*^9}},ExpressionUUID->"fce51adf-2f19-449f-9e95-\
308944874dfd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Transmitted", " ", "Shock"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"at", "[", "qt_", "]"}], ":=", 
    FractionBox[
     RowBox[{"2", " ", "\[Beta]"}], 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], " ", 
       RowBox[{"Cosh", "[", 
        RowBox[{"\[Zeta]r", "[", "qt", "]"}], "]"}]}], "+", 
      RowBox[{"\[Theta]", " ", 
       RowBox[{"Cosh", "[", "qt", "]"}]}]}]]}], " ", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"\\", "varphi_"}], 
     RowBox[{"{", 
      RowBox[{"1", "j"}], "}"}], " ", "in", " ", "transmitted", " ", 
     "variable"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bt", "[", "qt_", "]"}], ":=", 
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], 
       RowBox[{"Cosh", "[", 
        RowBox[{"\[Zeta]r", "[", "qt", "]"}], "]"}]}], "-", 
      RowBox[{"\[Theta]", " ", 
       RowBox[{"Cosh", "[", "qt", "]"}]}]}], 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], 
       RowBox[{"Cosh", "[", 
        RowBox[{"\[Zeta]r", "[", "qt", "]"}], "]"}]}], "+", 
      RowBox[{"\[Theta]", " ", 
       RowBox[{"Cosh", "[", "qt", "]"}]}]}]]}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"\\", "varphi_"}], 
     RowBox[{"{", 
      RowBox[{"2", "j"}], "}"}], " ", "in", " ", "transmitted", " ", 
     "variable"}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", 
           RowBox[{"--", 
            RowBox[{"--", 
             RowBox[{"--", 
              RowBox[{"--", 
               RowBox[{"--", 
                RowBox[{"--", 
                 RowBox[{"--", 
                  RowBox[{"--", 
                   RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{
                    "--", "--"}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}], 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Reflected", " ", "Shock"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ar", "[", "qr_", "]"}], ":=", 
    FractionBox[
     RowBox[{"2", " ", "\[Beta]"}], 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], 
       RowBox[{"Cosh", "[", "qr", "]"}]}], "+", 
      RowBox[{"\[Theta]", " ", 
       RowBox[{"Cosh", "[", 
        RowBox[{"\[Zeta]t", "[", "qr", "]"}], "]"}]}]}]]}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"\\", "varphi_"}], 
     RowBox[{"{", 
      RowBox[{"1", "j"}], "}"}], " ", "in", " ", "reflected", " ", 
     "variable"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"br", "[", "qr_", "]"}], ":=", 
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], 
       RowBox[{"Cosh", "[", "qr", "]"}]}], "-", 
      RowBox[{"\[Theta]", " ", 
       RowBox[{"Cosh", "[", 
        RowBox[{"\[Zeta]t", "[", "qr", "]"}], "]"}]}]}], 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], 
       RowBox[{"Cosh", "[", "qr", "]"}]}], "+", 
      RowBox[{"\[Theta]", " ", 
       RowBox[{"Cosh", "[", 
        RowBox[{"\[Zeta]t", "[", "qr", "]"}], "]"}]}]}]], 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"\\", "varphi_"}], 
      RowBox[{"{", 
       RowBox[{"2", "j"}], "}"}], " ", "in", " ", "reflected", " ", 
      "variable"}], "*)"}]}]}]}]], "Input",
 CellChangeTimes->{{3.925399727358727*^9, 3.925399844421619*^9}, {
   3.925399962656457*^9, 3.925399963637719*^9}, {3.9254349779534683`*^9, 
   3.925435018953869*^9}, {3.925462669091865*^9, 3.925462734087768*^9}, {
   3.92596282580447*^9, 3.925962881720828*^9}, {3.925962914228257*^9, 
   3.925962915825046*^9}, 3.925962970690591*^9, {3.933309973942345*^9, 
   3.933310034219922*^9}, {3.936327084045722*^9, 3.9363271149446993`*^9}, {
   3.936327172700323*^9, 3.936327202068078*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[46]:=",ExpressionUUID->"39e39a0f-dfc5-4ac8-865f-f2aa148af39f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Coefficients \[CapitalTheta]r (for both frequency variables) corresponding to \
(A17)\
\>", "Subsubsection",
 CellChangeTimes->{{3.9086013818432083`*^9, 3.90860140633117*^9}, {
  3.933312913749304*^9, 3.933312928742695*^9}, {3.936327238728507*^9, 
  3.9363272532654552`*^9}},ExpressionUUID->"9b2f487c-b634-44fd-8a46-\
40c7fca3bcf3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Transmitted", " ", "frequency"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalTheta]r1t", "[", "qt_", "]"}], ":=", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Ptsiso", "[", 
        RowBox[{"qt", "+", "\[Chi]ts"}], "]"}], 
       RowBox[{"\[Theta]", " ", 
        RowBox[{"at", "[", "qt", "]"}]}]]}], 
     FractionBox[
      RowBox[{"Cosh", "[", 
       RowBox[{"qt", "+", "\[Chi]ts"}], "]"}], 
      RowBox[{"Cosh", "[", "qt", "]"}]]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalTheta]r2t", "[", "qt_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"Cosh", "[", 
        RowBox[{"qt", "+", "\[Chi]ts"}], "]"}], 
       RowBox[{"Cosh", "[", "qt", "]"}]], " ", 
      FractionBox[
       RowBox[{"\[Alpha]t", "[", 
        RowBox[{"qt", "+", "\[Chi]ts"}], "]"}], 
       RowBox[{"\[Theta]", " ", 
        RowBox[{"at", "[", "qt", "]"}]}]]}], "-", " ", 
     FractionBox[
      RowBox[{"Sech", "[", "qt", "]"}], 
      RowBox[{"\[Theta]", " ", 
       RowBox[{"at", "[", "qt", "]"}]}]]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalTheta]r3t", "[", "qt_", "]"}], ":=", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"bt", "[", "qt", "]"}], " ", 
      RowBox[{"Sech", "[", "qt", "]"}]}], 
     RowBox[{"\[Theta]", " ", 
      RowBox[{"at", "[", "qt", "]"}]}]]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", 
           RowBox[{"--", 
            RowBox[{"--", 
             RowBox[{"--", 
              RowBox[{"--", 
               RowBox[{"--", 
                RowBox[{"--", 
                 RowBox[{"--", 
                  RowBox[{"--", 
                   RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{
                    "--", "--"}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}], 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Reflected", " ", "frequency"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalTheta]r1r", "[", "qr_", "]"}], ":=", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Ptsiso", "[", 
        RowBox[{
         RowBox[{"\[Zeta]t", "[", "qr", "]"}], "+", "\[Chi]ts"}], "]"}], 
       RowBox[{"\[Theta]", " ", 
        RowBox[{"at", "[", 
         RowBox[{"\[Zeta]t", "[", "qr", "]"}], "]"}]}]]}], 
     FractionBox[
      RowBox[{"Cosh", "[", 
       RowBox[{
        RowBox[{"\[Zeta]t", "[", "qr", "]"}], "+", "\[Chi]ts"}], "]"}], 
      RowBox[{"Cosh", "[", 
       RowBox[{"\[Zeta]t", "[", "qr", "]"}], "]"}]]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalTheta]r2r", "[", "qr_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"Cosh", "[", 
        RowBox[{
         RowBox[{"\[Zeta]t", "[", "qr", "]"}], "+", "\[Chi]ts"}], "]"}], 
       RowBox[{"Cosh", "[", 
        RowBox[{"\[Zeta]t", "[", "qr", "]"}], "]"}]], " ", 
      FractionBox[
       RowBox[{"\[Alpha]t", "[", 
        RowBox[{
         RowBox[{"\[Zeta]t", "[", "qr", "]"}], "+", "\[Chi]ts"}], "]"}], 
       RowBox[{"\[Theta]", " ", 
        RowBox[{"at", "[", 
         RowBox[{"\[Zeta]t", "[", "qr", "]"}], "]"}]}]]}], "-", " ", 
     FractionBox[
      RowBox[{"Sech", "[", 
       RowBox[{"\[Zeta]t", "[", "qr", "]"}], "]"}], 
      RowBox[{"\[Theta]", " ", 
       RowBox[{"at", "[", 
        RowBox[{"\[Zeta]t", "[", "qr", "]"}], "]"}]}]]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalTheta]r3r", "[", "qr_", "]"}], ":=", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"bt", "[", 
       RowBox[{"\[Zeta]t", "[", "qr", "]"}], "]"}], " ", 
      RowBox[{"Sech", "[", 
       RowBox[{"\[Zeta]t", "[", "qr", "]"}], "]"}]}], 
     RowBox[{"\[Theta]", " ", 
      RowBox[{"at", "[", 
       RowBox[{"\[Zeta]t", "[", "qr", "]"}], "]"}]}]]}]}]}]], "Input",
 CellChangeTimes->{{3.902505382600314*^9, 3.902505431762518*^9}, {
   3.902753504473679*^9, 3.902753518513725*^9}, {3.902903135818817*^9, 
   3.9029032127178*^9}, {3.9029032690541277`*^9, 3.902903272943746*^9}, {
   3.902903305496698*^9, 3.902903321445366*^9}, {3.902903557127766*^9, 
   3.9029035691810017`*^9}, {3.902906028585725*^9, 3.902906049075458*^9}, 
   3.902906179110714*^9, {3.903282121527904*^9, 3.903282151947397*^9}, {
   3.908600976773402*^9, 3.908600998996862*^9}, {3.908601033461475*^9, 
   3.908601167723762*^9}, {3.908601497018306*^9, 3.908601499636073*^9}, {
   3.91404877975089*^9, 3.914048791102922*^9}, {3.914049586219261*^9, 
   3.914049589859899*^9}, 3.914049990645109*^9, {3.9140673442416487`*^9, 
   3.91406734854707*^9}, {3.9254000488818502`*^9, 3.9254000980310287`*^9}, {
   3.925434557398134*^9, 3.925434599094365*^9}, {3.925434719263239*^9, 
   3.925434815321618*^9}, {3.9254627580446043`*^9, 3.925462770618211*^9}, 
   3.925462823459468*^9, 3.925463900175383*^9, 3.925463943760037*^9, {
   3.925465601886016*^9, 3.925465670839978*^9}, {3.92546598485633*^9, 
   3.925466042271373*^9}, {3.925962922769319*^9, 3.925962931474741*^9}, {
   3.933310063724044*^9, 3.933310085971225*^9}, {3.936327269961473*^9, 
   3.9363273158664417`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[50]:=",ExpressionUUID->"8deaee41-52a0-4472-9593-9a2b55f0d1e6"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.902505382600314*^9, 3.902505431762518*^9}, {
   3.902753504473679*^9, 3.902753518513725*^9}, {3.902903135818817*^9, 
   3.9029032127178*^9}, {3.9029032690541277`*^9, 3.902903272943746*^9}, {
   3.902903305496698*^9, 3.902903321445366*^9}, {3.902903557127766*^9, 
   3.9029035691810017`*^9}, {3.902906028585725*^9, 3.902906049075458*^9}, 
   3.902906179110714*^9, {3.903282121527904*^9, 3.903282151947397*^9}, {
   3.908600976773402*^9, 3.908600998996862*^9}, {3.908601033461475*^9, 
   3.908601167723762*^9}, {3.9086014377721643`*^9, 3.908601504138864*^9}, {
   3.908603728736595*^9, 3.908603731700537*^9}, {3.914048787120109*^9, 
   3.914048794173697*^9}, {3.914049659231526*^9, 3.914049661412503*^9}, 
   3.914049997268508*^9, {3.914067351227796*^9, 3.914067354952208*^9}, {
   3.925400112438418*^9, 3.925400142002195*^9}, {3.925434882429587*^9, 
   3.925434922034823*^9}, 3.9254350662784443`*^9, {3.925435147364355*^9, 
   3.925435212833295*^9}, {3.925462773828712*^9, 3.9254627839070263`*^9}, 
   3.925462833226796*^9, {3.9254628743175573`*^9, 3.9254628782932463`*^9}, {
   3.92546567315993*^9, 3.925465715776188*^9}, {3.925465897032357*^9, 
   3.925465898775528*^9}, {3.925466071264859*^9, 3.925466118553043*^9}, {
   3.925962934296887*^9, 3.925962941576443*^9}, {3.933310088510843*^9, 
   3.933310102436778*^9}, 
   3.936327268653079*^9},ExpressionUUID->"2acd89b0-9239-488e-84fa-\
2cdc634d7ee7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Coefficients \[CapitalTheta]t (for both frequency variables) corresponding to \
(A18)\
\>", "Subsubsection",
 CellChangeTimes->{{3.9086014188482428`*^9, 3.90860142856174*^9}, {
  3.933312952026379*^9, 3.933312952464115*^9}, {3.9363272593409033`*^9, 
  3.936327262442569*^9}},ExpressionUUID->"cf767cf6-be0c-4356-a813-\
7018387e6a13"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Transmitted", " ", "frequency"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalTheta]t1t", "[", "qt_", "]"}], ":=", 
    RowBox[{
     FractionBox[
      RowBox[{"Prsiso", "[", 
       RowBox[{
        RowBox[{"\[Zeta]r", "[", "qt", "]"}], "-", "\[Chi]rs"}], "]"}], 
      RowBox[{" ", 
       RowBox[{"ar", "[", 
        RowBox[{"\[Zeta]r", "[", "qt", "]"}], "]"}]}]], 
     FractionBox[
      RowBox[{"Cosh", "[", 
       RowBox[{
        RowBox[{"\[Zeta]r", "[", "qt", "]"}], "-", "\[Chi]rs"}], "]"}], 
      RowBox[{"Cosh", "[", 
       RowBox[{"\[Zeta]r", "[", "qt", "]"}], "]"}]]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalTheta]t2t", "[", "qt_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"Cosh", "[", 
        RowBox[{
         RowBox[{"\[Zeta]r", "[", "qt", "]"}], "-", "\[Chi]rs"}], "]"}], 
       RowBox[{"Cosh", "[", 
        RowBox[{"\[Zeta]r", "[", "qt", "]"}], "]"}]], " ", 
      FractionBox[
       RowBox[{"\[Alpha]r", "[", 
        RowBox[{
         RowBox[{"\[Zeta]r", "[", "qt", "]"}], "-", "\[Chi]rs"}], "]"}], 
       RowBox[{"ar", "[", 
        RowBox[{"\[Zeta]r", "[", "qt", "]"}], "]"}]]}], "-", " ", 
     FractionBox[
      RowBox[{"Sech", "[", 
       RowBox[{"\[Zeta]r", "[", "qt", "]"}], "]"}], 
      RowBox[{"ar", "[", 
       RowBox[{"\[Zeta]r", "[", "qt", "]"}], "]"}]]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalTheta]t3t", "[", "qt_", "]"}], ":=", 
    RowBox[{"-", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"br", "[", 
        RowBox[{"\[Zeta]r", "[", "qt", "]"}], "]"}], " ", 
       RowBox[{"Sech", "[", 
        RowBox[{"\[Zeta]r", "[", "qt", "]"}], "]"}]}], 
      RowBox[{"ar", "[", 
       RowBox[{"\[Zeta]r", "[", "qt", "]"}], "]"}]]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", 
           RowBox[{"--", 
            RowBox[{"--", 
             RowBox[{"--", 
              RowBox[{"--", 
               RowBox[{"--", 
                RowBox[{"--", 
                 RowBox[{"--", 
                  RowBox[{"--", 
                   RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{
                    "--", "--"}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}], 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Reflected", " ", "frequency"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalTheta]t1r", "[", "qr_", "]"}], ":=", 
    RowBox[{
     FractionBox[
      RowBox[{"Prsiso", "[", 
       RowBox[{"qr", "-", "\[Chi]rs"}], "]"}], 
      RowBox[{" ", 
       RowBox[{"ar", "[", "qr", "]"}]}]], 
     FractionBox[
      RowBox[{"Cosh", "[", 
       RowBox[{"qr", "-", "\[Chi]rs"}], "]"}], 
      RowBox[{"Cosh", "[", "qr", "]"}]]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalTheta]t2r", "[", "qr_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"Cosh", "[", 
        RowBox[{"qr", "-", "\[Chi]rs"}], "]"}], 
       RowBox[{"Cosh", "[", "qr", "]"}]], " ", 
      FractionBox[
       RowBox[{"\[Alpha]r", "[", 
        RowBox[{"qr", "-", "\[Chi]rs"}], "]"}], 
       RowBox[{"ar", "[", "qr", "]"}]]}], "-", " ", 
     FractionBox[
      RowBox[{"Sech", "[", "qr", "]"}], 
      RowBox[{"ar", "[", "qr", "]"}]]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalTheta]t3r", "[", "qr_", "]"}], ":=", 
    RowBox[{"-", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"br", "[", "qr", "]"}], " ", 
       RowBox[{"Sech", "[", "qr", "]"}]}], 
      RowBox[{"ar", "[", "qr", "]"}]]}]}]}]}]], "Input",
 CellChangeTimes->{{3.902505382600314*^9, 3.902505431762518*^9}, {
   3.902753504473679*^9, 3.902753518513725*^9}, {3.902903135818817*^9, 
   3.9029032127178*^9}, {3.9029032690541277`*^9, 3.902903272943746*^9}, {
   3.902903305496698*^9, 3.902903321445366*^9}, {3.902903557127766*^9, 
   3.9029035691810017`*^9}, {3.902906028585725*^9, 3.902906049075458*^9}, 
   3.902906179110714*^9, {3.903282121527904*^9, 3.903282151947397*^9}, {
   3.908600976773402*^9, 3.908600998996862*^9}, {3.908601033461475*^9, 
   3.908601167723762*^9}, {3.908601497018306*^9, 3.908601499636073*^9}, {
   3.91404877975089*^9, 3.914048791102922*^9}, {3.914049586219261*^9, 
   3.914049589859899*^9}, 3.914049990645109*^9, {3.9140673442416487`*^9, 
   3.91406734854707*^9}, {3.9254000488818502`*^9, 3.9254000980310287`*^9}, {
   3.925434557398134*^9, 3.925434599094365*^9}, {3.925434719263239*^9, 
   3.925434815321618*^9}, {3.925435299548309*^9, 3.925435430106772*^9}, {
   3.925435474775789*^9, 3.925435545220559*^9}, {3.925435634086442*^9, 
   3.925435639613301*^9}, {3.92546288284754*^9, 3.925462898091461*^9}, {
   3.92546312576157*^9, 3.925463132545299*^9}, 3.925465775294825*^9, {
   3.925465842530826*^9, 3.925465864544763*^9}, {3.925466177783833*^9, 
   3.925466235544042*^9}, {3.936327338660893*^9, 3.936327358313962*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[56]:=",ExpressionUUID->"c8351bec-69c1-4783-8abc-c0bbee8020d7"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fixed point iteration: ", "Subsection",
 CellChangeTimes->{{3.90478709949612*^9, 3.904787132263801*^9}, 
   3.904787498862177*^9, {3.925530312388359*^9, 3.925530320082895*^9}, 
   3.936327433390811*^9},ExpressionUUID->"091822a1-6d63-4064-bb46-\
44b40086f760"],

Cell["The derivation is fully explained in the section A.3. ", "Text",
 CellChangeTimes->{{3.936327439771717*^9, 
  3.936327477477646*^9}},ExpressionUUID->"7b993d05-0e53-4f55-a293-\
75e56a6c727b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"itFrm", "[", 
   RowBox[{"0", ",", "qr_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"\[CapitalTheta]r1r", "[", "qr", "]"}], "+", 
    RowBox[{
     RowBox[{"\[CapitalTheta]t1r", "[", "qr", "]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[CapitalTheta]r2r", "[", "qr", "]"}], "+", 
       RowBox[{"\[CapitalTheta]r3r", "[", "qr", "]"}]}], ")"}]}]}], 
   RowBox[{"1", "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[CapitalTheta]t2r", "[", "qr", "]"}], "+", 
       RowBox[{"\[CapitalTheta]t3r", "[", "qr", "]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[CapitalTheta]r2r", "[", "qr", "]"}], "+", 
       RowBox[{"\[CapitalTheta]r3r", "[", "qr", "]"}]}], 
      ")"}]}]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"itFtM", "[", 
   RowBox[{"0", ",", "qt_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"\[CapitalTheta]t1t", "[", "qt", "]"}], "+", 
   RowBox[{
    RowBox[{"\[CapitalTheta]t3t", "[", "qt", "]"}], 
    RowBox[{"itFrm", "[", 
     RowBox[{"0", ",", 
      RowBox[{"\[Zeta]r", "[", "qt", "]"}]}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"\[CapitalTheta]t2t", "[", "qt", "]"}], 
    RowBox[{"itFrm", "[", 
     RowBox[{"0", ",", 
      RowBox[{
       RowBox[{"\[Zeta]r", "[", "qt", "]"}], "-", 
       RowBox[{"2", "\[Chi]rs"}]}]}], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"itFrm", "[", 
   RowBox[{"n_", ",", "qr_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"\[CapitalTheta]r1r", "[", "qr", "]"}], "+", 
     RowBox[{
      RowBox[{"\[CapitalTheta]t1r", "[", "qr", "]"}], 
      RowBox[{"\[CapitalTheta]r3r", "[", "qr", "]"}]}]}], 
    RowBox[{"1", "-", 
     RowBox[{
      RowBox[{"\[CapitalTheta]t3r", "[", "qr", "]"}], 
      RowBox[{"\[CapitalTheta]r3r", "[", "qr", "]"}]}]}]], "+", 
   RowBox[{
    FractionBox[
     RowBox[{"\[CapitalTheta]r2r", "[", "qr", "]"}], 
     RowBox[{"1", "-", 
      RowBox[{
       RowBox[{"\[CapitalTheta]t3r", "[", "qr", "]"}], 
       RowBox[{"\[CapitalTheta]r3r", "[", "qr", "]"}]}]}]], 
    RowBox[{"itFtM", "[", 
     RowBox[{
      RowBox[{"n", "-", "1"}], ",", 
      RowBox[{
       RowBox[{"\[Zeta]t", "[", "qr", "]"}], "+", 
       RowBox[{"2", "\[Chi]ts"}]}]}], "]"}]}], "+", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"\[CapitalTheta]t2r", "[", "qr", "]"}], 
      RowBox[{"\[CapitalTheta]r3r", "[", "qr", "]"}]}], 
     RowBox[{"1", "-", 
      RowBox[{
       RowBox[{"\[CapitalTheta]t3r", "[", "qr", "]"}], 
       RowBox[{"\[CapitalTheta]r3r", "[", "qr", "]"}]}]}]], 
    RowBox[{"itFrm", "[", 
     RowBox[{
      RowBox[{"n", "-", "1"}], ",", 
      RowBox[{"qr", "-", 
       RowBox[{"2", "\[Chi]rs"}]}]}], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"itFtM", "[", 
   RowBox[{"n_", ",", "qt_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"\[CapitalTheta]t1t", "[", "qt", "]"}], "+", 
     RowBox[{
      RowBox[{"\[CapitalTheta]r1t", "[", "qt", "]"}], 
      RowBox[{"\[CapitalTheta]t3t", "[", "qt", "]"}]}]}], 
    RowBox[{"1", "-", 
     RowBox[{
      RowBox[{"\[CapitalTheta]t3t", "[", "qt", "]"}], 
      RowBox[{"\[CapitalTheta]r3t", "[", "qt", "]"}]}]}]], "+", 
   RowBox[{
    FractionBox[
     RowBox[{"\[CapitalTheta]t2t", "[", "qt", "]"}], 
     RowBox[{"1", "-", 
      RowBox[{
       RowBox[{"\[CapitalTheta]t3t", "[", "qt", "]"}], 
       RowBox[{"\[CapitalTheta]r3t", "[", "qt", "]"}]}]}]], 
    RowBox[{"itFrm", "[", 
     RowBox[{
      RowBox[{"n", "-", "1"}], ",", 
      RowBox[{
       RowBox[{"\[Zeta]r", "[", "qt", "]"}], "-", 
       RowBox[{"2", "\[Chi]rs"}]}]}], "]"}]}], "+", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"\[CapitalTheta]r2t", "[", "qt", "]"}], 
      RowBox[{"\[CapitalTheta]t3t", "[", "qt", "]"}]}], 
     RowBox[{"1", "-", 
      RowBox[{
       RowBox[{"\[CapitalTheta]t3t", "[", "qt", "]"}], 
       RowBox[{"\[CapitalTheta]r3t", "[", "qt", "]"}]}]}]], 
    RowBox[{"itFtM", "[", 
     RowBox[{
      RowBox[{"n", "-", "1"}], ",", 
      RowBox[{"qt", "+", 
       RowBox[{"2", "\[Chi]ts"}]}]}], "]"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.908601669744952*^9, 3.908601849779969*^9}, {
  3.908601914475337*^9, 3.9086019557211246`*^9}, {3.9086051863743563`*^9, 
  3.908605186546647*^9}, {3.908605716018455*^9, 3.908605730799431*^9}, {
  3.9086058659045343`*^9, 3.908605869841177*^9}, {3.9254635952808123`*^9, 
  3.925463606037959*^9}, {3.936327395129073*^9, 3.9363274107435904`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[62]:=",ExpressionUUID->"778ccddb-a509-4220-a5e3-ffb3f1919842"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Expressions for the acoustic functions ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Ft", "-"], TraditionalForm]],ExpressionUUID->
  "b442bb95-9918-45c8-af2b-3432038cb541"],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Fr", "+"], TraditionalForm]],ExpressionUUID->
  "bf0a5e8a-6d3f-4bf3-bec1-58f8d43ce373"],
 ":"
}], "Subsection",
 CellChangeTimes->{{3.90478709949612*^9, 3.904787132263801*^9}, 
   3.904787498862177*^9},ExpressionUUID->"c2754193-d0de-4116-a9c4-\
23a408efa830"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"itFtm", "[", 
   RowBox[{"n_", ",", "qt_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Alpha]t", "[", 
        RowBox[{"qt", "+", "\[Chi]ts"}], "]"}], 
       RowBox[{"Cosh", "[", 
        RowBox[{"qt", "+", "\[Chi]ts"}], "]"}]}], "-", "1"}], ")"}], 
    RowBox[{"itFtM", "[", 
     RowBox[{"n", ",", 
      RowBox[{"qt", "+", 
       RowBox[{"2", "\[Chi]ts"}]}]}], "]"}]}], "-", 
   RowBox[{
    RowBox[{"Ptsiso", "[", 
     RowBox[{"qt", "+", "\[Chi]ts"}], "]"}], " ", 
    RowBox[{"Cosh", "[", 
     RowBox[{"qt", "+", "\[Chi]ts"}], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"itFrM", "[", 
   RowBox[{"n_", ",", "qr_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Alpha]r", "[", 
        RowBox[{"qr", "-", "\[Chi]rs"}], "]"}], 
       RowBox[{"Cosh", "[", 
        RowBox[{"qr", "-", "\[Chi]rs"}], "]"}]}], "-", "1"}], ")"}], 
    RowBox[{"itFrm", "[", 
     RowBox[{"n", ",", 
      RowBox[{"qr", "-", 
       RowBox[{"2", "\[Chi]rs"}]}]}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"Prsiso", "[", 
     RowBox[{"qr", "-", "\[Chi]rs"}], "]"}], 
    RowBox[{"Cosh", "[", 
     RowBox[{"qr", "-", "\[Chi]rs"}], "]"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.904787135547199*^9, 3.90478735797721*^9}, {
   3.904787391298875*^9, 3.904787442372031*^9}, {3.904794777403092*^9, 
   3.904794793522067*^9}, {3.908519750433514*^9, 3.908519771170127*^9}, 
   3.908519804080864*^9, {3.908522164466818*^9, 3.908522165417074*^9}, {
   3.908522612538314*^9, 3.908522616062949*^9}, {3.908524933169359*^9, 
   3.908524941640141*^9}, {3.90860310481448*^9, 3.908603132890271*^9}, {
   3.925462995064727*^9, 3.9254630669046583`*^9}, {3.925463782608451*^9, 
   3.925463795846058*^9}, {3.936327492174567*^9, 3.936327492413596*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[66]:=",ExpressionUUID->"501ba51f-f719-49ba-a75f-a809d6dfce2e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "THE FUNCTIONS ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    TemplateBox[<|"boxes" -> FormBox[
        SubscriptBox[
         StyleBox["P", "TI"], 
         StyleBox["j", "TI"]], TraditionalForm], "errors" -> {}, "input" -> 
      "P_j", "state" -> "Boxes"|>,
     "TeXAssistantTemplate"], " "}], TraditionalForm]],ExpressionUUID->
  "7eea90d9-7a12-4d02-8bb9-8772bc8b22f0"],
 "and ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       SubscriptBox[
        StyleBox["L", "TI"], 
        StyleBox["j", "TI"]], TraditionalForm], "errors" -> {}, "input" -> 
     "L_j", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],ExpressionUUID->
  "036c7cea-ceea-4f4a-903e-4bfacf22d3b9"]
}], "Section",
 CellChangeTimes->{{3.904790727804624*^9, 3.904790734724335*^9}, {
   3.906775451968621*^9, 3.906775461150829*^9}, {3.91447046726417*^9, 
   3.91447048440536*^9}, {3.914470532386592*^9, 3.914470569376563*^9}, {
   3.925471741381101*^9, 3.925471768261682*^9}, 3.925552752971953*^9, {
   3.936327534626195*^9, 
   3.936327570570216*^9}},ExpressionUUID->"cfbb30ea-c9f0-4bc9-8e14-\
33a7988fb5f2"],

Cell[CellGroupData[{

Cell["Transmitted Field", "Subsection",
 CellChangeTimes->{{3.904790741893149*^9, 
  3.904790749627898*^9}},ExpressionUUID->"2b7ca307-c304-4c7f-a79d-\
04dc30cc059e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"PLt", "[", 
    RowBox[{"n_", ",", "qt_", ",", "\[Chi]_"}], "]"}], ":=", 
   FractionBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"itFtM", "[", 
       RowBox[{"n", ",", 
        RowBox[{"qt", "+", "\[Chi]"}]}], "]"}], "+", 
      RowBox[{"itFtm", "[", 
       RowBox[{"n", ",", 
        RowBox[{"qt", "-", "\[Chi]"}]}], "]"}]}], ")"}], 
    RowBox[{"Cosh", "[", "qt", "]"}]]}], 
  RowBox[{"(*", 
   RowBox[{"Laplace", " ", "pressure", " ", "transmitted"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LLt", "[", 
    RowBox[{"n_", ",", "qt_", ",", "\[Chi]_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"itFtm", "[", 
     RowBox[{"n", ",", 
      RowBox[{"qt", "-", "\[Chi]"}]}], "]"}], "-", 
    RowBox[{"itFtM", "[", 
     RowBox[{"n", ",", 
      RowBox[{"qt", "+", "\[Chi]"}]}], "]"}]}]}], 
  RowBox[{"(*", 
   RowBox[{"Laplace", " ", "pressure", " ", "gradient", " ", "transmitted"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"qut", "[", "st_", "]"}], " ", ":=", " ", 
  RowBox[{"Log", "[", 
   RowBox[{"st", " ", "+", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"st", "^", "2"}], " ", "+", " ", "1"}]]}], "]"}], 
  RowBox[{"(*", 
   RowBox[{"frequency", " ", "coordinate", " ", "transmitted"}], 
   "*)"}]}]}], "Input",
 CellChangeTimes->{{3.904790753695457*^9, 3.90479089807103*^9}, {
   3.9047911859767036`*^9, 3.904791194574863*^9}, {3.904794847322875*^9, 
   3.9047948692177896`*^9}, 3.9047952150491858`*^9, {3.904795258275544*^9, 
   3.904795270732106*^9}, {3.904795735141053*^9, 3.904795735243836*^9}, 
   3.904795766237248*^9, {3.904795850302198*^9, 3.904795874800359*^9}, {
   3.9047959536804457`*^9, 3.904795956262773*^9}, {3.908519445215293*^9, 
   3.908519460471873*^9}, {3.908519617146324*^9, 3.90851961997654*^9}, {
   3.90852498037379*^9, 3.908524988713545*^9}, {3.908603165386204*^9, 
   3.908603227448916*^9}, {3.908603390129623*^9, 3.908603393193996*^9}, {
   3.908613078716145*^9, 3.908613081028776*^9}, {3.926744608070212*^9, 
   3.926744612060184*^9}, {3.933310511115525*^9, 3.9333105217189093`*^9}, {
   3.933310822704211*^9, 3.93331085118946*^9}, {3.936327543187518*^9, 
   3.936327543478531*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[68]:=",ExpressionUUID->"cc3cb73b-f067-4586-a692-4766c7bbfc98"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reflected field", "Subsection",
 CellChangeTimes->{{3.904791431766803*^9, 
  3.904791455182822*^9}},ExpressionUUID->"188a8542-e1c1-4202-8ee4-\
239167a66ccb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"PLr", "[", 
    RowBox[{"n_", ",", "qr_", ",", "\[Chi]_"}], "]"}], ":=", 
   FractionBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"itFrM", "[", 
       RowBox[{"n", ",", 
        RowBox[{"qr", "+", "\[Chi]"}]}], "]"}], "+", 
      RowBox[{"itFrm", "[", 
       RowBox[{"n", ",", 
        RowBox[{"qr", "-", "\[Chi]"}]}], "]"}]}], ")"}], 
    RowBox[{"Cosh", "[", "qr", "]"}]]}], 
  RowBox[{"(*", 
   RowBox[{"Laplace", " ", "pressure", " ", "reflected"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LLr", "[", 
    RowBox[{"n_", ",", "qr_", ",", "\[Chi]_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"itFrm", "[", 
     RowBox[{"n", ",", 
      RowBox[{"qr", "-", "\[Chi]"}]}], "]"}], "-", 
    RowBox[{"itFrM", "[", 
     RowBox[{"n", ",", 
      RowBox[{"qr", "+", "\[Chi]"}]}], "]"}]}]}], 
  RowBox[{"(*", 
   RowBox[{"Laplace", " ", "pressure", " ", "gradient", " ", "reflected"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"qur", "[", "sr_", "]"}], " ", ":=", " ", 
  RowBox[{"Log", "[", 
   RowBox[{"sr", " ", "+", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"sr", "^", "2"}], " ", "+", " ", "1"}]]}], "]"}], 
  RowBox[{"(*", 
   RowBox[{"frequency", " ", "coordinate", " ", "reflected"}], 
   "*)"}]}]}], "Input",
 CellChangeTimes->{{3.904790753695457*^9, 3.90479089807103*^9}, {
   3.9047911859767036`*^9, 3.904791194574863*^9}, {3.904794847322875*^9, 
   3.9047948692177896`*^9}, 3.9047952150491858`*^9, {3.904795258275544*^9, 
   3.904795270732106*^9}, {3.904795735141053*^9, 3.904795735243836*^9}, 
   3.904795766237248*^9, {3.904795850302198*^9, 3.904795874800359*^9}, {
   3.9047959536804457`*^9, 3.904795956262773*^9}, {3.908519445215293*^9, 
   3.908519460471873*^9}, {3.908519617146324*^9, 3.90851961997654*^9}, {
   3.90852498037379*^9, 3.908524988713545*^9}, {3.908603165386204*^9, 
   3.908603227448916*^9}, {3.908603390129623*^9, 3.908603393193996*^9}, {
   3.908612578562133*^9, 3.908612625505722*^9}, {3.908613066417773*^9, 
   3.9086130695406427`*^9}, {3.909033368164997*^9, 3.909033368556898*^9}, {
   3.925530498446171*^9, 3.925530498969095*^9}, {3.926744621844918*^9, 
   3.926744624860048*^9}, {3.933310580786228*^9, 3.933310586683855*^9}, {
   3.933310859915837*^9, 3.933310875656535*^9}, {3.93632757877398*^9, 
   3.936327579351222*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[71]:=",ExpressionUUID->"f13ee2be-5846-4670-9212-93b1d04aad9b"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Growth rate calculation", "Chapter",
 CellChangeTimes->{{3.92164513571932*^9, 3.921645136473733*^9}, {
  3.925469988283807*^9, 3.92546999160196*^9}, {3.936327632878141*^9, 
  3.936327635148378*^9}},ExpressionUUID->"a5ed659d-71ac-4923-979e-\
4157241debd6"],

Cell[CellGroupData[{

Cell[TextData[{
 "Calculation of the asymptotic growth rate: ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       SubsuperscriptBox[
        OverscriptBox[
         StyleBox["u", "TI"], "_"], 
        RowBox[{
          StyleBox["t", "TI"], 
          StyleBox["i", "TI"]}], "\[Infinity]"], TraditionalForm], 
     "errors" -> {}, "input" -> "\\bar{u}_{ti}^{\\infty}", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],ExpressionUUID->
  "6411ad7b-92ac-43a0-84ff-dd2f88b0734c"]
}], "Section",
 CellChangeTimes->{{3.926737939518619*^9, 3.926737957831994*^9}, {
  3.936327781329102*^9, 
  3.936327794570664*^9}},ExpressionUUID->"404ca317-e7d4-44fa-8ebe-\
8c4020f603fc"],

Cell[CellGroupData[{

Cell["Calculation by (4.20)", "Subsection",
 CellChangeTimes->{{3.9363278853167953`*^9, 
  3.93632789762669*^9}},ExpressionUUID->"fe7f9b4c-5be5-4bb0-a76f-\
f9fb17aa69e1"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalOmega]t", " ", ":=", 
   RowBox[{"N", "[", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Rt", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", "ht"}], ")"}]}], 
      RowBox[{"2", "M2t"}]], ",", "prec"}], "]"}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"transmitted", " ", "vorticity", " ", "parameter"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalOmega]r", " ", ":=", 
   RowBox[{"N", "[", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Rr", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", "hr"}], ")"}]}], 
      RowBox[{"2", "M2r"}]], ",", "prec"}], "]"}]}], 
  RowBox[{"(*", 
   RowBox[{"reflected", " ", "vorticity", " ", "parameter"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vt0", " ", ":=", 
   RowBox[{"N", "[", " ", 
    RowBox[{
     RowBox[{"\[Xi]t0", " ", "M2t", " ", 
      RowBox[{"(", 
       RowBox[{"Rt", "-", "1"}], ")"}]}], ",", "prec"}], "]"}]}], 
  RowBox[{"(*", 
   RowBox[{"transmitted", " ", "initial", " ", "tangetial", " ", "velocity"}],
    "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vr0", ":=", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[Xi]r0"}], " ", "M2r", 
      RowBox[{"(", 
       RowBox[{"Rr", "-", "1"}], ")"}]}], ",", "prec"}], "]"}]}], 
  RowBox[{"(*", 
   RowBox[{"reflected", " ", "vorticity", " ", "tangetial", " ", "velocity"}],
    "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<\[CapitalOmega]t = \>\"", ",", "\[CapitalOmega]t"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<\[CapitalOmega]r = \>\"", ",", "\[CapitalOmega]r"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<vt0 = \>\"", ",", "vt0"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<vr0 = \>\"", ",", "vr0"}], "]"}]}], "Input",
 CellChangeTimes->{{3.906691550499173*^9, 3.906691613153076*^9}, {
  3.908430729581215*^9, 3.908430737979319*^9}, {3.925470131431878*^9, 
  3.925470148243226*^9}, {3.925554754223578*^9, 3.925554791314152*^9}, {
  3.926745309184989*^9, 3.926745364061522*^9}, {3.926745540846551*^9, 
  3.926745544879856*^9}, {3.9333105949311547`*^9, 3.933310627332972*^9}, {
  3.933310913060297*^9, 3.933310974248554*^9}, {3.933311534881179*^9, 
  3.9333115383177147`*^9}, {3.9363276464922457`*^9, 3.936327733285739*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[74]:=",ExpressionUUID->"9b46ec8f-731e-433e-9e25-5183d8ecffa2"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\[CapitalOmega]t = \"\>", "\[InvisibleSpace]", 
   "0.18205964679733513`"}],
  SequenceForm["\[CapitalOmega]t = ", 0.18205964679733513`],
  Editable->False]], "Print",
 CellChangeTimes->{3.9363277360350103`*^9},
 CellLabel->
  "During evaluation of \
In[74]:=",ExpressionUUID->"a03a9c0e-c3d9-4b48-8952-9f9bd4a57e1d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\[CapitalOmega]r = \"\>", "\[InvisibleSpace]", 
   "0.006181929905375312`"}],
  SequenceForm["\[CapitalOmega]r = ", 0.006181929905375312],
  Editable->False]], "Print",
 CellChangeTimes->{3.936327736037057*^9},
 CellLabel->
  "During evaluation of \
In[74]:=",ExpressionUUID->"f6b8dddd-358b-4639-b626-c3b701e691de"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"vt0 = \"\>", "\[InvisibleSpace]", "0.11146498681564035`"}],
  SequenceForm["vt0 = ", 0.11146498681564035`],
  Editable->False]], "Print",
 CellChangeTimes->{3.9363277360387363`*^9},
 CellLabel->
  "During evaluation of \
In[74]:=",ExpressionUUID->"d172fbb1-0f4b-4dfd-ad55-3a0a12b4346e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"vr0 = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.1331579326432311`"}]}],
  SequenceForm["vr0 = ", -0.1331579326432311],
  Editable->False]], "Print",
 CellChangeTimes->{3.9363277360394087`*^9},
 CellLabel->
  "During evaluation of \
In[74]:=",ExpressionUUID->"cf3dbfe0-3d93-4e9b-aa8f-c2299229f347"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"utinfty", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", " ", 
       RowBox[{"vt0", "-", 
        RowBox[{
         FractionBox["\[Theta]", "\[Beta]"], "vr0"}]}], ")"}], "+", 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"\[CapitalOmega]t", " ", 
         RowBox[{"Sinh", "[", "\[Chi]ts", "]"}], " ", 
         RowBox[{"PLt", "[", 
          RowBox[{"10", ",", "\[Chi]ts", ",", "\[Chi]ts"}], "]"}]}], "+", 
        RowBox[{"\[CapitalOmega]r", "  ", 
         FractionBox["\[Theta]", "\[Beta]"], " ", 
         RowBox[{"PLr", "[", 
          RowBox[{"5", ",", 
           RowBox[{"-", "\[Chi]rs"}], ",", "\[Chi]rs"}], "]"}], 
         RowBox[{"Sinh", "[", "\[Chi]rs", "]"}]}]}], ")"}]}], ")"}], 
    RowBox[{"(", 
     FractionBox[
      SuperscriptBox["\[Beta]", "2"], 
      RowBox[{
       SuperscriptBox["\[Beta]", "2"], "+", "\[Theta]"}]], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<The asymptotic growth rate calculated by the method proposed in \
Wouchuk (2001) renders that \!\(\*TemplateBox[<|\"boxes\" -> FormBox[
SubsuperscriptBox[
OverscriptBox[
StyleBox[\"u\", \"TI\"], \"_\"], 
RowBox[{
StyleBox[\"t\", \"TI\"], 
StyleBox[\"i\", \"TI\"]}], \"\[Infinity]\"], TraditionalForm], \"errors\" -> \
{}, \"input\" -> \"\\\\bar{u}_{ti}^{\\\\infty}\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\) = \>\"", ",", "utinfty"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.906691969116399*^9, 3.906692200661623*^9}, {
   3.906692232693426*^9, 3.906692271062811*^9}, 3.90678126544802*^9, {
   3.907419074705289*^9, 3.907419080745807*^9}, {3.907426689120034*^9, 
   3.907426693091901*^9}, {3.907473500544194*^9, 3.907473510796396*^9}, {
   3.907474395806159*^9, 3.9074744014532747`*^9}, {3.907474589303409*^9, 
   3.907474639275881*^9}, {3.9074764261050873`*^9, 3.9074764936113663`*^9}, {
   3.907476794012467*^9, 3.907476798720108*^9}, {3.90747684063622*^9, 
   3.907476885407098*^9}, {3.9074774763452387`*^9, 3.907477501604433*^9}, {
   3.90747757135312*^9, 3.907477574402215*^9}, {3.907477867019712*^9, 
   3.907477873132385*^9}, {3.907478714495576*^9, 3.907478751936425*^9}, {
   3.907478932128154*^9, 3.907478950523415*^9}, {3.907478996484273*^9, 
   3.907479032230035*^9}, {3.907479097386324*^9, 3.9074791202517033`*^9}, {
   3.90747920731933*^9, 3.9074792161647863`*^9}, {3.907479398539715*^9, 
   3.907479466849479*^9}, {3.907479721817863*^9, 3.907479737615707*^9}, {
   3.907479832028944*^9, 3.90747985565996*^9}, {3.907479891061433*^9, 
   3.907479940023349*^9}, {3.907479973353707*^9, 3.907479975490172*^9}, {
   3.907480038496633*^9, 3.907480048053072*^9}, {3.907480113662387*^9, 
   3.907480120731139*^9}, {3.907480245366125*^9, 3.907480366401859*^9}, {
   3.907480404875493*^9, 3.907480441872329*^9}, {3.90748401647775*^9, 
   3.9074840399988527`*^9}, {3.907484182832361*^9, 3.907484208342834*^9}, {
   3.907484255747249*^9, 3.907484256047058*^9}, {3.907484370639575*^9, 
   3.907484408289895*^9}, {3.907484439236937*^9, 3.907484442789233*^9}, 
   3.907484571854408*^9, {3.907484614880362*^9, 3.90748463035231*^9}, 
   3.907484676891897*^9, {3.907486122187169*^9, 3.90748615617445*^9}, {
   3.907507061244549*^9, 3.90750711368116*^9}, {3.907507163800201*^9, 
   3.907507167687407*^9}, {3.907507210862389*^9, 3.907507241887535*^9}, 
   3.907507370877715*^9, {3.907507529208488*^9, 3.907507540345439*^9}, {
   3.907507741504154*^9, 3.907507767001906*^9}, {3.907508006107502*^9, 
   3.907508092202379*^9}, {3.907508136055335*^9, 3.9075081417412443`*^9}, {
   3.907508192849246*^9, 3.907508220470011*^9}, {3.907508311594904*^9, 
   3.907508348805375*^9}, {3.9075083947546787`*^9, 3.90750840354653*^9}, 
   3.9075084422180643`*^9, {3.907508551900525*^9, 3.907508584398144*^9}, {
   3.907509253784329*^9, 3.907509274758*^9}, {3.90750986390753*^9, 
   3.907509876342415*^9}, {3.907509935378119*^9, 3.90751000616553*^9}, {
   3.907510038677144*^9, 3.907510043716428*^9}, {3.907510091903585*^9, 
   3.907510109933895*^9}, {3.907510248291304*^9, 3.907510306130655*^9}, {
   3.907510593241848*^9, 3.907510608176155*^9}, {3.907510676594449*^9, 
   3.907510728042259*^9}, {3.90751078526554*^9, 3.9075108257872*^9}, 
   3.907510866214565*^9, {3.90751093617136*^9, 3.907510938919183*^9}, {
   3.907518991800654*^9, 3.907519007194957*^9}, {3.907519045505784*^9, 
   3.907519060126137*^9}, {3.907593820251958*^9, 3.907593886382578*^9}, {
   3.90759395884039*^9, 3.907593963076432*^9}, {3.907594010704122*^9, 
   3.907594037365283*^9}, {3.907594076629455*^9, 3.907594081859068*^9}, {
   3.907594386963871*^9, 3.907594508304706*^9}, 3.907594667595014*^9, {
   3.907594699671894*^9, 3.907594785810566*^9}, {3.907594918372305*^9, 
   3.907594964424939*^9}, {3.9075955748495626`*^9, 3.907595610690542*^9}, {
   3.907595748404455*^9, 3.907595784252988*^9}, {3.907595944317156*^9, 
   3.907595947352762*^9}, {3.907595989506493*^9, 3.90759599733451*^9}, 
   3.907596062767267*^9, {3.907596217665319*^9, 3.907596231228227*^9}, {
   3.9076754228052063`*^9, 3.907675423803216*^9}, {3.907734231469419*^9, 
   3.907734293037183*^9}, {3.907996634702581*^9, 3.90799667222281*^9}, {
   3.9080064354003687`*^9, 3.908006442981588*^9}, {3.908613881605494*^9, 
   3.908613884722935*^9}, {3.908613975325366*^9, 3.9086139797847023`*^9}, {
   3.925393745710606*^9, 3.925393761794851*^9}, {3.92539379433361*^9, 
   3.925393968914423*^9}, {3.9253940334732533`*^9, 3.925394057088121*^9}, 
   3.925394117342239*^9, {3.925394235891147*^9, 3.925394357380864*^9}, {
   3.925394427953573*^9, 3.9253944349928017`*^9}, {3.925394523521574*^9, 
   3.925394554134743*^9}, {3.925398255422984*^9, 3.925398256733916*^9}, 
   3.9254632221341*^9, {3.925467613193858*^9, 3.92546765534193*^9}, {
   3.925468899107279*^9, 3.925468899824334*^9}, {3.925469962555415*^9, 
   3.925469975273704*^9}, {3.925875268056915*^9, 3.925875284840308*^9}, {
   3.925875362968842*^9, 3.925875363666936*^9}, {3.926738314536641*^9, 
   3.926738316516899*^9}, {3.92674536864502*^9, 3.926745399258043*^9}, {
   3.926745525900031*^9, 3.926745529762099*^9}, {3.933310630941451*^9, 
   3.933310656727458*^9}, {3.933310806895319*^9, 3.933310818394744*^9}, {
   3.933310979687495*^9, 3.9333109866351433`*^9}, {3.936327902234433*^9, 
   3.9363280013582706`*^9}, {3.936328096386282*^9, 3.936328110451054*^9}, {
   3.9363286628134823`*^9, 3.936328665245072*^9}},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "In[103]:=",ExpressionUUID->"45ad9c34-d6e3-4b41-9d5c-3250f1f5a0d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The asymptotic growth rate calculated by the method proposed \
in Wouchuk (2001) renders that \\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[SubsuperscriptBox[OverscriptBox[StyleBox[\\\"u\\\", \\\"TI\\\"], \
\\\"_\\\"], RowBox[{StyleBox[\\\"t\\\", \\\"TI\\\"], StyleBox[\\\"i\\\", \
\\\"TI\\\"]}], \\\"\[Infinity]\\\"], TraditionalForm], \\\"errors\\\" -> {}, \
\\\"input\\\" -> \\\"\\\\\\\\bar{u}_{ti}^{\\\\\\\\infty}\\\", \\\"state\\\" \
-> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\) = \"\>", 
   "\[InvisibleSpace]", "0.1357794895818485`"}],
  SequenceForm[
  "The asymptotic growth rate calculated by the method proposed in Wouchuk \
(2001) renders that \!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[SubsuperscriptBox[OverscriptBox[StyleBox[\"u\", \"TI\"], \"_\"], \
RowBox[{StyleBox[\"t\", \"TI\"], StyleBox[\"i\", \"TI\"]}], \"\[Infinity]\"], \
TraditionalForm], \"errors\" -> {}, \"input\" -> \
\"\\\\bar{u}_{ti}^{\\\\infty}\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\) = ", 0.1357794895818485],
  Editable->False]], "Print",
 CellChangeTimes->{3.936328004707439*^9, 3.936328111864812*^9, 
  3.936328673729616*^9},
 CellLabel->
  "During evaluation of \
In[103]:=",ExpressionUUID->"7888b505-c7fe-4e31-80b6-ed9b7cc64d90"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculation of utinfty by (4.16)", "Subsection",
 CellChangeTimes->{{3.9254701983862123`*^9, 3.925470209611553*^9}, {
  3.936328045667885*^9, 
  3.936328049034984*^9}},ExpressionUUID->"0c6f9512-4271-4b02-af8b-\
2e1fa4045d2e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"uinftyTVF", " ", "=", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"itFtm", "[", 
       RowBox[{"5", ",", 
        RowBox[{"qut", "[", 
         SuperscriptBox["10", 
          RowBox[{"-", "100"}]], "]"}]}], "]"}], "-", 
      RowBox[{"itFtM", "[", 
       RowBox[{"5", ",", 
        RowBox[{"qut", "[", 
         SuperscriptBox["10", 
          RowBox[{"-", "100"}]], "]"}]}], "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<The asymptotic growth rate by  the appliacation of the Final Value \
theorem renders that \!\(\*TemplateBox[<|\"boxes\" -> FormBox[
SubsuperscriptBox[
OverscriptBox[
StyleBox[\"u\", \"TI\"], \"_\"], 
RowBox[{
StyleBox[\"t\", \"TI\"], 
StyleBox[\"i\", \"TI\"]}], \"\[Infinity]\"], TraditionalForm], \"errors\" -> \
{}, \"input\" -> \"\\\\bar{u}_{ti}^{\\\\infty}\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\) = \>\"", ",", "utinfty"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.92547038165022*^9, 3.925470387859618*^9}, {
   3.925531569825719*^9, 3.925531586133193*^9}, {3.926737884917365*^9, 
   3.926737887516334*^9}, {3.926737918735976*^9, 3.926737920646308*^9}, 
   3.926737961104187*^9, {3.926738444442611*^9, 3.926738445360549*^9}, {
   3.933310996369607*^9, 3.933311004335165*^9}, {3.9363280670562153`*^9, 
   3.93632807687744*^9}, {3.9363281224282637`*^9, 3.936328148833336*^9}, {
   3.9363286672389593`*^9, 3.936328670403921*^9}},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "In[105]:=",ExpressionUUID->"544d3810-dce0-44f5-ac36-4787406b9f70"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The asymptotic growth rate by  the appliacation of the Final \
Value theorem renders that \\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[SubsuperscriptBox[OverscriptBox[StyleBox[\\\"u\\\", \\\"TI\\\"], \
\\\"_\\\"], RowBox[{StyleBox[\\\"t\\\", \\\"TI\\\"], StyleBox[\\\"i\\\", \
\\\"TI\\\"]}], \\\"\[Infinity]\\\"], TraditionalForm], \\\"errors\\\" -> {}, \
\\\"input\\\" -> \\\"\\\\\\\\bar{u}_{ti}^{\\\\\\\\infty}\\\", \\\"state\\\" \
-> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\) = \"\>", 
   "\[InvisibleSpace]", "0.1357794895818485`"}],
  SequenceForm[
  "The asymptotic growth rate by  the appliacation of the Final Value theorem \
renders that \!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[SubsuperscriptBox[OverscriptBox[StyleBox[\"u\", \"TI\"], \"_\"], \
RowBox[{StyleBox[\"t\", \"TI\"], StyleBox[\"i\", \"TI\"]}], \"\[Infinity]\"], \
TraditionalForm], \"errors\" -> {}, \"input\" -> \
\"\\\\bar{u}_{ti}^{\\\\infty}\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\) = ", 0.1357794895818485],
  Editable->False]], "Print",
 CellChangeTimes->{3.936328150032463*^9, 3.936328675404378*^9},
 CellLabel->
  "During evaluation of \
In[105]:=",ExpressionUUID->"d0c2e50f-56eb-48ba-9654-b8c228744d52"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculation of the evolution uinterface", "Section",
 CellChangeTimes->{{3.925470225714897*^9, 
  3.92547024566746*^9}},ExpressionUUID->"67fad244-d548-4dbc-831e-\
d07e7f0dcfe4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"uacoustictrasnmittedinterface", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"Re", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2", "Pi"]}], " ", 
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Im", "[", 
            FractionBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"itFtm", "[", 
                RowBox[{"5", ",", 
                 RowBox[{"qut", "[", 
                  RowBox[{"I", " ", "z"}], "]"}]}], "]"}], "-", 
               RowBox[{"itFtM", "[", 
                RowBox[{"5", ",", 
                 RowBox[{"qut", "[", 
                  RowBox[{"I", " ", "z"}], "]"}]}], "]"}]}], ")"}], 
             RowBox[{"I", " ", "z"}]], "]"}], 
           RowBox[{"Sin", "[", 
            RowBox[{"t", " ", "z"}], "]"}]}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"z", ",", " ", "0", ",", " ", "\[Beta]"}], "}"}]}], 
         "]"}]}], "]"}], ")"}]}], "//", "Quiet"}]}], "  ", 
  RowBox[{"(*", 
   RowBox[{"integral", " ", "expresion"}], "*)"}], 
  "  "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"datauacoustictrasnmittedintegraleq", "[", "tf_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t", ",", 
        RowBox[{"uacoustictrasnmittedinterface", "[", " ", "t", " ", "]"}]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "tf", " ", ",", "0.4"}], "}"}]}], "]"}], "//",
     "Quiet"}]}], 
  RowBox[{"(*", 
   RowBox[{"numerical", " ", "solution"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Datauacoustictransmittedilt", " ", "=", 
    RowBox[{"datauacoustictrasnmittedintegraleq", "[", "20", "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"data", " ", "points"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Datauacoustictransmittedinterpolated", " ", "=", " ", 
    RowBox[{"Interpolation", "[", 
     RowBox[{"Datauacoustictransmittedilt", ",", 
      RowBox[{"InterpolationOrder", "->", "3"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "interpolation", " ", "of", " ", "the", " ", "numerical", " ", "data"}], 
   " ", "*)"}], "                      "}]}], "Input",
 CellChangeTimes->{{3.907385007352206*^9, 3.907385051980962*^9}, {
   3.907385140357106*^9, 3.90738526291363*^9}, {3.907385341827924*^9, 
   3.907385456148043*^9}, {3.90738623306258*^9, 3.907386257386988*^9}, {
   3.907387150629024*^9, 3.907387259768167*^9}, {3.907397407534458*^9, 
   3.907397515081784*^9}, {3.907397594806917*^9, 3.907397597259576*^9}, 
   3.9073977398814*^9, {3.907397853839901*^9, 3.907397860175475*^9}, {
   3.907398130260387*^9, 3.907398222513042*^9}, 3.907398275629142*^9, {
   3.907418018804665*^9, 3.907418078561001*^9}, 3.90742656295298*^9, {
   3.9074269294086237`*^9, 3.9074269391082163`*^9}, {3.907485126124959*^9, 
   3.907485126807381*^9}, {3.90748517448917*^9, 3.907485237749007*^9}, {
   3.907732405382963*^9, 3.907732428518057*^9}, {3.907732459010958*^9, 
   3.907732466771556*^9}, 3.907771513300419*^9, 3.907771675052734*^9, {
   3.907771864956016*^9, 3.90777187439754*^9}, {3.907775343610075*^9, 
   3.90777534839636*^9}, {3.907775580899786*^9, 3.9077756114652023`*^9}, {
   3.907775667073499*^9, 3.907775669825285*^9}, {3.907917103103142*^9, 
   3.907917142288148*^9}, {3.907917302003417*^9, 3.907917313311889*^9}, {
   3.907917758573666*^9, 3.907917766754418*^9}, {3.907917814601495*^9, 
   3.907917831480587*^9}, {3.907919450632881*^9, 3.907919455717267*^9}, {
   3.90793617947575*^9, 3.907936189003099*^9}, {3.907938858275566*^9, 
   3.907938865577138*^9}, {3.9079948295535316`*^9, 3.907994831242502*^9}, {
   3.907994976315133*^9, 3.907994977643918*^9}, 3.907995545826214*^9, {
   3.907999392954212*^9, 3.907999425445026*^9}, 3.9079994621292257`*^9, {
   3.908013540754678*^9, 3.9080135497918253`*^9}, 3.908013580859659*^9, 
   3.908017390438079*^9, {3.908422263627541*^9, 3.908422264914435*^9}, {
   3.908430998647072*^9, 3.908431005714237*^9}, 3.908508509237853*^9, {
   3.908607410069048*^9, 3.908607416660536*^9}, {3.908607518628758*^9, 
   3.908607528435285*^9}, 3.908612837873241*^9, {3.925366943228475*^9, 
   3.925366948124504*^9}, {3.925367294254224*^9, 3.925367294731448*^9}, {
   3.925470251382496*^9, 3.9254702739314613`*^9}, {3.926742070712715*^9, 
   3.92674207084662*^9}, {3.926745455784295*^9, 3.926745459460624*^9}, {
   3.9333115462513137`*^9, 3.933311546936219*^9}, {3.936328196457309*^9, 
   3.936328219150383*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->"In[88]:=",ExpressionUUID->"83ac2475-a52f-4abd-a9c0-2c25ce904530"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"visualization", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Datauacoustictransmittedinterpolated", "[", "x", "]"}], ",", 
        "utinfty", ",", "uinftyTVF"}], " ", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "20"}], "}"}], ",", 
      RowBox[{"PlotRange", "->", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "20"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0.165"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "->", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Black"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Black", ",", 
           RowBox[{"Dashing", "[", "Large", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "DotDashed", ",", "myred"}], "}"}]}], "}"}]}],
       ",", 
      RowBox[{"AxesLabel", "->", 
       RowBox[{"{", 
        RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<uti(t)\>\""}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "->", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Temporal evolution\>\"", ",", "\"\<Expression (4.20)\>\"", ",", 
          "\"\<Expression (4.16)\>\""}], "}"}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "->", 
       RowBox[{"1", "/", "2"}]}]}], "]"}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.927630947721608*^9, 3.927630950192849*^9}, 
   3.927630981139566*^9, 3.927632244764943*^9, {3.927632344572153*^9, 
   3.927632345306953*^9}, {3.927632686828055*^9, 3.92763269374893*^9}, {
   3.927633878263231*^9, 3.927633885506659*^9}, {3.927633981550254*^9, 
   3.927633992494879*^9}, {3.927685980795402*^9, 3.927686018645306*^9}, {
   3.927686307362508*^9, 3.927686318070384*^9}, {3.927686834978407*^9, 
   3.927686849715837*^9}, {3.9276870032508507`*^9, 3.92768700333521*^9}, {
   3.9276883070806417`*^9, 3.927688314478239*^9}, {3.927793820298603*^9, 
   3.927793820832048*^9}, {3.92779423253274*^9, 3.927794236083281*^9}, 
   3.927885306083144*^9, {3.93331113806877*^9, 3.933311196868241*^9}, {
   3.933311735420716*^9, 3.933311786827412*^9}, {3.933312140002676*^9, 
   3.933312140609617*^9}, {3.933312170655732*^9, 3.9333121712296877`*^9}, {
   3.9363282452535954`*^9, 3.936328266562374*^9}, {3.936328297659584*^9, 
   3.9363283239787807`*^9}, {3.93632846135828*^9, 3.93632846598897*^9}, 
   3.9363285025237417`*^9, {3.936328556586721*^9, 3.936328573032786*^9}, 
   3.936328635218738*^9, {3.936328714834484*^9, 3.936328778918581*^9}, {
   3.936328822341476*^9, 3.936328857070073*^9}},
 Background->RGBColor[0.88, 1, 0.88],
 CellLabel->
  "In[111]:=",ExpressionUUID->"2d64c341-6ce9-4f9e-bdfd-ed1eb6fc11d3"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    InterpretationBox[{
      TagBox[{{{{}, {}, 
          TagBox[{
            Directive[
             Opacity[1.], 
             AbsoluteThickness[2], 
             Thickness[Large], 
             GrayLevel[0]], 
            LineBox[CompressedData["
1:eJwc2nc81d8bAHBbVtlkz4trXZcQch5toiEiSWYhlCQySkhZJQ2SaFDIKCVZ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             "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
          TagBox[{
            Directive[
             Opacity[1.], 
             AbsoluteThickness[2], 
             Thickness[Large], 
             GrayLevel[0], 
             Dashing[Large]], 
            LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQPbcuic0wZbbdidg5Ly0SD9qz336k/lb+pD2Mv/DU
/MLX8jfh/HXrO2/n6L2C89PtL858U/QZzs97qvl4y7qfcD6XYov6fQsGBxi/
T+C01sIEZjg/6XbIfuYzbHB+4dGWpHx1Ljh/YwFPsIQnL5y/sDr7lUG4AJzf
NP9P4Jc3gnA+w+UHDnuqhOF8tZK0ihAtUTj/ydfpYdx7xeB8r6dZtZMKJeB8
vycTtOXkpOD8V4eTGk6slYbz9QSvyTrHy8L5XPZfE+98loPz3d9GfVcKVYDz
bxxKYYzSUYTzt3YciVP4iuCnsZY+OHdOCc5PLqreyjNLGc7XT9c+55OoAuef
F9LhLrVUhfN3r2uarcOsBudXM2oFnLmL4HPdqfLI26IO5z9dpjhlfo0GnD9F
Q5JlZ6gmnD9hVtrxRAUtOD9qSuw5nucI/g+XpT/n79OG8x8/dao41K4D5y+y
NZQ+m6gL569tLRVM19WD89tDk72ZvyL4pncWrmw/qw/nz9CcvfastwGcX3+g
d4b3TgTfVzp06SkVQzjfMe94tGAngj9fJknlzFcEX+Xw8ml+0UYI/+ke0rq0
D8FP+8xy8aSWMSI9bvyk0NmP4E+4xNN75DiCv++z2s///xF8AHqskb4=
             "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
          TagBox[{
            Directive[
             Opacity[1.], 
             AbsoluteThickness[2], 
             Thickness[Large], 
             Dashing[{0, Small, Small, Small}], 
             RGBColor[
              NCache[
               Rational[44, 51], 0.8627450980392157], 
              NCache[
               Rational[14, 51], 0.27450980392156865`], 
              NCache[
               Rational[16, 51], 0.3137254901960784]]], 
            LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQPbcuic0wZbbdidg5Ly0SD9qz336k/lb+pD2Mv/DU
/MLX8jfh/HXrO2/n6L2C89PtL858U/QZzs97qvl4y7qfcD6XYov6fQsGBxi/
T+C01sIEZjg/6XbIfuYzbHB+4dGWpHx1Ljh/YwFPsIQnL5y/sDr7lUG4AJzf
NP9P4Jc3gnA+w+UHDnuqhOF8tZK0ihAtUTj/ydfpYdx7xeB8r6dZtZMKJeB8
vycTtOXkpOD8V4eTGk6slYbz9QSvyTrHy8L5XPZfE+98loPz3d9GfVcKVYDz
bxxKYYzSUYTzt3YciVP4iuCnsZY+OHdOCc5PLqreyjNLGc7XT9c+55OoAuef
F9LhLrVUhfN3r2uarcOsBudXM2oFnLmL4HPdqfLI26IO5z9dpjhlfo0GnD9F
Q5JlZ6gmnD9hVtrxRAUtOD9qSuw5nucI/g+XpT/n79OG8x8/dao41K4D5y+y
NZQ+m6gL569tLRVM19WD89tDk72ZvyL4pncWrmw/qw/nz9CcvfastwGcX3+g
d4b3TgTfVzp06SkVQzjfMe94tGAngj9fJknlzFcEX+Xw8ml+0UYI/+ke0rq0
D8FP+8xy8aSWMSI9bvyk0NmP4E+4xNN75DiCv++z2s///xF8AHqskb4=
             "]]}, Annotation[#, "Charting`Private`Tag#3"]& ]}}, {}}, {
       "WolframDynamicHighlight", <|
        "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
      StyleBox[
       DynamicBox[
        (Charting`HighlightActionBox["DynamicHighlight", {}, 
         Slot["HighlightElements"], 
         Slot["LayoutOptions"], 
         Slot["Meta"], 
         Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
             Annotation[{
               Directive[
                Opacity[1.], 
                AbsoluteThickness[2], 
                Thickness[Large], 
                GrayLevel[0]], 
               Line[CompressedData["
1:eJwc2nc81d8bAHBbVtlkz4trXZcQch5toiEiSWYhlCQySkhZJQ2SaFDIKCVZ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                "]]}, "Charting`Private`Tag#1"], 
             Annotation[{
               Directive[
                Opacity[1.], 
                AbsoluteThickness[2], 
                Thickness[Large], 
                GrayLevel[0], 
                Dashing[Large]], 
               Line[CompressedData["
1:eJxTTMoPSmViYGAwAWIQPbcuic0wZbbdidg5Ly0SD9qz336k/lb+pD2Mv/DU
/MLX8jfh/HXrO2/n6L2C89PtL858U/QZzs97qvl4y7qfcD6XYov6fQsGBxi/
T+C01sIEZjg/6XbIfuYzbHB+4dGWpHx1Ljh/YwFPsIQnL5y/sDr7lUG4AJzf
NP9P4Jc3gnA+w+UHDnuqhOF8tZK0ihAtUTj/ydfpYdx7xeB8r6dZtZMKJeB8
vycTtOXkpOD8V4eTGk6slYbz9QSvyTrHy8L5XPZfE+98loPz3d9GfVcKVYDz
bxxKYYzSUYTzt3YciVP4iuCnsZY+OHdOCc5PLqreyjNLGc7XT9c+55OoAuef
F9LhLrVUhfN3r2uarcOsBudXM2oFnLmL4HPdqfLI26IO5z9dpjhlfo0GnD9F
Q5JlZ6gmnD9hVtrxRAUtOD9qSuw5nucI/g+XpT/n79OG8x8/dao41K4D5y+y
NZQ+m6gL569tLRVM19WD89tDk72ZvyL4pncWrmw/qw/nz9CcvfastwGcX3+g
d4b3TgTfVzp06SkVQzjfMe94tGAngj9fJknlzFcEX+Xw8ml+0UYI/+ke0rq0
D8FP+8xy8aSWMSI9bvyk0NmP4E+4xNN75DiCv++z2s///xF8AHqskb4=
                "]]}, "Charting`Private`Tag#2"], 
             Annotation[{
               Directive[
                Opacity[1.], 
                AbsoluteThickness[2], 
                Thickness[Large], 
                Dashing[{0, Small, Small, Small}], 
                RGBColor[
                 Rational[44, 51], 
                 Rational[14, 51], 
                 Rational[16, 51]]], 
               Line[CompressedData["
1:eJxTTMoPSmViYGAwAWIQPbcuic0wZbbdidg5Ly0SD9qz336k/lb+pD2Mv/DU
/MLX8jfh/HXrO2/n6L2C89PtL858U/QZzs97qvl4y7qfcD6XYov6fQsGBxi/
T+C01sIEZjg/6XbIfuYzbHB+4dGWpHx1Ljh/YwFPsIQnL5y/sDr7lUG4AJzf
NP9P4Jc3gnA+w+UHDnuqhOF8tZK0ihAtUTj/ydfpYdx7xeB8r6dZtZMKJeB8
vycTtOXkpOD8V4eTGk6slYbz9QSvyTrHy8L5XPZfE+98loPz3d9GfVcKVYDz
bxxKYYzSUYTzt3YciVP4iuCnsZY+OHdOCc5PLqreyjNLGc7XT9c+55OoAuef
F9LhLrVUhfN3r2uarcOsBudXM2oFnLmL4HPdqfLI26IO5z9dpjhlfo0GnD9F
Q5JlZ6gmnD9hVtrxRAUtOD9qSuw5nucI/g+XpT/n79OG8x8/dao41K4D5y+y
NZQ+m6gL569tLRVM19WD89tDk72ZvyL4pncWrmw/qw/nz9CcvfastwGcX3+g
d4b3TgTfVzp06SkVQzjfMe94tGAngj9fJknlzFcEX+Xw8ml+0UYI/+ke0rq0
D8FP+8xy8aSWMSI9bvyk0NmP4E+4xNN75DiCv++z2s///xF8AHqskb4=
                "]]}, "Charting`Private`Tag#3"]}}, {}}, <|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PanelPlotLayout" -> <||>, 
             "PlotRange" -> {{0., 20.}, {0., 0.165}}, 
             "Frame" -> {{False, False}, {False, False}}, 
             "AxesOrigin" -> {0, 0}, "ImageSize" -> {576, 288}, 
             "Axes" -> {True, True}, "LabelStyle" -> 
             Directive[
              FontFamily -> "CMU Serif", FontSlant -> Plain, FontSize -> 18, 
               RGBColor[0, 0, 0]], "AspectRatio" -> Rational[1, 2], 
             "DefaultStyle" -> {
               Directive[
                Opacity[1.], 
                AbsoluteThickness[2], 
                Thickness[Large], 
                Dashing[{0, Small, Small, Small}], 
                RGBColor[
                 Rational[44, 51], 
                 Rational[14, 51], 
                 Rational[16, 51]]], 
               Directive[
                Opacity[1.], 
                AbsoluteThickness[2], 
                Thickness[Large], 
                GrayLevel[0], 
                Dashing[Large]], 
               Directive[
                Opacity[1.], 
                AbsoluteThickness[2], 
                Thickness[Large], 
                GrayLevel[0]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> Plot, "GroupHighlight" -> False|>|>]]& )[<|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, "PlotRange" -> {{0., 20.}, {0., 0.165}},
             "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0, 0}, "ImageSize" -> {576, 288}, 
            "Axes" -> {True, True}, "LabelStyle" -> 
            Directive[
             FontFamily -> "CMU Serif", FontSlant -> Plain, FontSize -> 18, 
              RGBColor[0, 0, 0]], "AspectRatio" -> Rational[1, 2], 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               Thickness[Large], 
               Dashing[{0, Small, Small, Small}], 
               RGBColor[
                Rational[44, 51], 
                Rational[14, 51], 
                Rational[16, 51]]], 
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               Thickness[Large], 
               GrayLevel[0], 
               Dashing[Large]], 
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               Thickness[Large], 
               GrayLevel[0]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]], Selectable -> False]}, 
     Annotation[{{{{}, {}, 
         Annotation[{
           Directive[
            Opacity[1.], 
            AbsoluteThickness[2], 
            Thickness[Large], 
            GrayLevel[0]], 
           Line[CompressedData["
1:eJwc2nc81d8bAHBbVtlkz4trXZcQch5toiEiSWYhlCQySkhZJQ2SaFDIKCVZ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            "]]}, "Charting`Private`Tag#1"], 
         Annotation[{
           Directive[
            Opacity[1.], 
            AbsoluteThickness[2], 
            Thickness[Large], 
            GrayLevel[0], 
            Dashing[Large]], 
           Line[CompressedData["
1:eJxTTMoPSmViYGAwAWIQPbcuic0wZbbdidg5Ly0SD9qz336k/lb+pD2Mv/DU
/MLX8jfh/HXrO2/n6L2C89PtL858U/QZzs97qvl4y7qfcD6XYov6fQsGBxi/
T+C01sIEZjg/6XbIfuYzbHB+4dGWpHx1Ljh/YwFPsIQnL5y/sDr7lUG4AJzf
NP9P4Jc3gnA+w+UHDnuqhOF8tZK0ihAtUTj/ydfpYdx7xeB8r6dZtZMKJeB8
vycTtOXkpOD8V4eTGk6slYbz9QSvyTrHy8L5XPZfE+98loPz3d9GfVcKVYDz
bxxKYYzSUYTzt3YciVP4iuCnsZY+OHdOCc5PLqreyjNLGc7XT9c+55OoAuef
F9LhLrVUhfN3r2uarcOsBudXM2oFnLmL4HPdqfLI26IO5z9dpjhlfo0GnD9F
Q5JlZ6gmnD9hVtrxRAUtOD9qSuw5nucI/g+XpT/n79OG8x8/dao41K4D5y+y
NZQ+m6gL569tLRVM19WD89tDk72ZvyL4pncWrmw/qw/nz9CcvfastwGcX3+g
d4b3TgTfVzp06SkVQzjfMe94tGAngj9fJknlzFcEX+Xw8ml+0UYI/+ke0rq0
D8FP+8xy8aSWMSI9bvyk0NmP4E+4xNN75DiCv++z2s///xF8AHqskb4=
            "]]}, "Charting`Private`Tag#2"], 
         Annotation[{
           Directive[
            Opacity[1.], 
            AbsoluteThickness[2], 
            Thickness[Large], 
            Dashing[{0, Small, Small, Small}], 
            RGBColor[
             Rational[44, 51], 
             Rational[14, 51], 
             Rational[16, 51]]], 
           Line[CompressedData["
1:eJxTTMoPSmViYGAwAWIQPbcuic0wZbbdidg5Ly0SD9qz336k/lb+pD2Mv/DU
/MLX8jfh/HXrO2/n6L2C89PtL858U/QZzs97qvl4y7qfcD6XYov6fQsGBxi/
T+C01sIEZjg/6XbIfuYzbHB+4dGWpHx1Ljh/YwFPsIQnL5y/sDr7lUG4AJzf
NP9P4Jc3gnA+w+UHDnuqhOF8tZK0ihAtUTj/ydfpYdx7xeB8r6dZtZMKJeB8
vycTtOXkpOD8V4eTGk6slYbz9QSvyTrHy8L5XPZfE+98loPz3d9GfVcKVYDz
bxxKYYzSUYTzt3YciVP4iuCnsZY+OHdOCc5PLqreyjNLGc7XT9c+55OoAuef
F9LhLrVUhfN3r2uarcOsBudXM2oFnLmL4HPdqfLI26IO5z9dpjhlfo0GnD9F
Q5JlZ6gmnD9hVtrxRAUtOD9qSuw5nucI/g+XpT/n79OG8x8/dao41K4D5y+y
NZQ+m6gL569tLRVM19WD89tDk72ZvyL4pncWrmw/qw/nz9CcvfastwGcX3+g
d4b3TgTfVzp06SkVQzjfMe94tGAngj9fJknlzFcEX+Xw8ml+0UYI/+ke0rq0
D8FP+8xy8aSWMSI9bvyk0NmP4E+4xNN75DiCv++z2s///xF8AHqskb4=
            "]]}, "Charting`Private`Tag#3"]}}, {}}, <|
      "HighlightElements" -> <|
        "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
       "LayoutOptions" -> <|
        "PanelPlotLayout" -> <||>, "PlotRange" -> {{0., 20.}, {0., 0.165}}, 
         "Frame" -> {{False, False}, {False, False}}, "AxesOrigin" -> {0, 0}, 
         "ImageSize" -> {576, 288}, "Axes" -> {True, True}, "LabelStyle" -> 
         Directive[
          FontFamily -> "CMU Serif", FontSlant -> Plain, FontSize -> 18, 
           RGBColor[0, 0, 0]], "AspectRatio" -> Rational[1, 2], 
         "DefaultStyle" -> {
           Directive[
            Opacity[1.], 
            AbsoluteThickness[2], 
            Thickness[Large], 
            Dashing[{0, Small, Small, Small}], 
            RGBColor[
             Rational[44, 51], 
             Rational[14, 51], 
             Rational[16, 51]]], 
           Directive[
            Opacity[1.], 
            AbsoluteThickness[2], 
            Thickness[Large], 
            GrayLevel[0], 
            Dashing[Large]], 
           Directive[
            Opacity[1.], 
            AbsoluteThickness[2], 
            Thickness[Large], 
            GrayLevel[0]]}, 
         "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), 
           "ScalingFunctions" -> {{Identity, Identity}, {
             Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
       "Meta" -> <|
        "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
         Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]], {
    DisplayFunction -> Identity, DisplayFunction -> Identity, 
     Ticks -> {Automatic, Automatic}, AxesOrigin -> {0, 0}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{0, 0}, {0, 0}}, PlotRangeClipping -> True, 
     ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[1, 2], 0.5], Axes -> {True, True}, AxesLabel -> {
       FormBox[
        TagBox["\"\[Tau]\"", HoldForm], TraditionalForm], 
       FormBox[
        TagBox["\"uti(t)\"", HoldForm], TraditionalForm]}, 
     AxesOrigin -> {0, 0}, 
     BaseStyle -> {
      FontFamily -> "CMU Serif", FontSlant -> Plain, FontSize -> 20}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Large, LabelStyle -> 
     Directive[
      FontFamily -> "CMU Serif", FontSlant -> Plain, FontSize -> 18, 
       RGBColor[0, 0, 0]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0., 20.}, {0., 0.165}}, 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     RotateLabel -> False, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"Temporal evolution\"", "\"Expression (4.20)\"", 
       "\"Expression (4.16)\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "CMU Serif", FontSlant -> 
                    Plain, FontSize -> 20, 
                    Opacity[1.], 
                    AbsoluteThickness[2], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 12.5}, {40, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "CMU Serif", FontSlant -> 
                    Plain, FontSize -> 20, 
                    Opacity[1.], 
                    AbsoluteThickness[2], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "CMU Serif", FontSlant -> 
                    Plain, FontSize -> 20, 
                    Opacity[1.], 
                    AbsoluteThickness[2], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Large]], {
                    LineBox[{{0, 12.5}, {40, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "CMU Serif", FontSlant -> 
                    Plain, FontSize -> 20, 
                    Opacity[1.], 
                    AbsoluteThickness[2], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "CMU Serif", FontSlant -> 
                    Plain, FontSize -> 20, 
                    Opacity[1.], 
                    AbsoluteThickness[2], 
                    Thickness[Large], 
                    Dashing[{0, Small, Small, Small}], 
                    RGBColor[
                    NCache[
                    Rational[44, 51], 0.8627450980392157], 
                    NCache[
                    Rational[14, 51], 0.27450980392156865`], 
                    NCache[
                    Rational[16, 51], 0.3137254901960784]]], {
                    LineBox[{{0, 12.5}, {40, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "CMU Serif", FontSlant -> 
                    Plain, FontSize -> 20, 
                    Opacity[1.], 
                    AbsoluteThickness[2], 
                    Thickness[Large], 
                    Dashing[{0, Small, Small, Small}], 
                    RGBColor[
                    NCache[
                    Rational[44, 51], 0.8627450980392157], 
                    NCache[
                    Rational[14, 51], 0.27450980392156865`], 
                    NCache[
                    Rational[16, 51], 0.3137254901960784]]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {40, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          Directive[
          FontFamily -> "CMU Serif", FontSlant -> Plain, FontSize -> 18, 
           RGBColor[0, 0, 0]], FontFamily -> "Arial"}, Background -> 
         Automatic, StripOnInput -> False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"CMU Serif\""}], ",", 
                   RowBox[{"FontSlant", "\[Rule]", "Plain"}], ",", 
                   RowBox[{"FontSize", "\[Rule]", "20"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"CMU Serif\""}], ",", 
                   RowBox[{"FontSlant", "\[Rule]", "Plain"}], ",", 
                   RowBox[{"FontSize", "\[Rule]", "20"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"], ",", 
                   RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"CMU Serif\""}], ",", 
                   RowBox[{"FontSlant", "\[Rule]", "Plain"}], ",", 
                   RowBox[{"FontSize", "\[Rule]", "20"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Small", ",", "Small", ",", "Small"}], 
                    "}"}], "]"}], ",", 
                   TemplateBox[<|"color" -> RGBColor[
                    Rational[44, 51], 
                    Rational[14, 51], 
                    Rational[16, 51]]|>, "RGBColorSwatchTemplate"]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"Directive", "[", 
               RowBox[{
                 RowBox[{"FontFamily", "\[Rule]", "\"CMU Serif\""}], ",", 
                 RowBox[{"FontSlant", "\[Rule]", "Plain"}], ",", 
                 RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                 
                 TemplateBox[<|"color" -> RGBColor[0, 0, 0]|>, 
                  "RGBColorSwatchTemplate"]}], "]"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.936328646967079*^9, 3.936328660609919*^9}, 
   3.936328702439217*^9, 3.9363287793894577`*^9, 3.936328857714488*^9},
 CellLabel->
  "Out[111]=",ExpressionUUID->"1447291a-460a-43f2-a6d1-6d4bee33df1c"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1512, 833},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
SpellingDictionaries->{"CorrectWords"->{
 "Hugoniot", "\[Alpha]\[CloseCurlyQuote]s", "pressurespacexytransmitted", 
  "pressurespacexyreflected", "Wommersley", "Ritchmyer", "Meshkov", 
  "uinterface", "utinfty", "Ricthmyer", "Cobos", "Velikovich", "Huete", 
  "Napieralski"}},
FrontEndVersion->"14.0 for Mac OS X ARM (64-bit) (December 12, 2023)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"cde2254b-608f-4367-902c-25e9e42f0379"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 325, 5, 98, "Title",ExpressionUUID->"221d62ef-f87e-4ae8-ae59-271d3a76b034"],
Cell[CellGroupData[{
Cell[930, 31, 434, 11, 45, "Subsubsection",ExpressionUUID->"07f27839-b6a7-4ccb-addd-a8339160cab7"],
Cell[1367, 44, 1056, 20, 143, "Text",ExpressionUUID->"80a5e2fd-be1f-4b38-81b2-c7c51ec9f6dc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2460, 69, 167, 3, 69, "Chapter",ExpressionUUID->"9742315d-542b-4839-ba5c-3c7a550c1644"],
Cell[CellGroupData[{
Cell[2652, 76, 214, 4, 67, "Section",ExpressionUUID->"49dd84d4-d6e0-4e41-b11f-74ae5bc397bb"],
Cell[2869, 82, 739, 18, 89, "Input",ExpressionUUID->"60912529-a365-43a2-827d-86bb52c5839a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3645, 105, 210, 4, 67, "Section",ExpressionUUID->"06afa9a3-3d35-444e-afb0-03735e33380e"],
Cell[3858, 111, 1423, 32, 73, "Input",ExpressionUUID->"e343ac79-5969-4d47-beae-261f8151f9b9"],
Cell[5284, 145, 1265, 36, 202, "Input",ExpressionUUID->"2b20ab53-041e-4d5e-928f-4a2aac05fe87"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6598, 187, 272, 4, 69, "Chapter",ExpressionUUID->"0db2606d-ede3-4caa-be17-c224a0f8bb8f"],
Cell[6873, 193, 1949, 31, 488, "Input",ExpressionUUID->"0a0c2f1b-1bb4-4b0a-b653-2e0ee9417ae8"]
}, Closed]],
Cell[CellGroupData[{
Cell[8859, 229, 319, 5, 58, "Chapter",ExpressionUUID->"bd933514-24a4-469a-aaf0-60fec6af7039"],
Cell[CellGroupData[{
Cell[9203, 238, 252, 4, 54, "Subsection",ExpressionUUID->"888fd9c8-eca0-406b-9e43-d7ab9d92af75"],
Cell[9458, 244, 1147, 35, 161, "Input",ExpressionUUID->"b35602b7-c0c9-4e1d-8be5-b6ebb272471f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10642, 284, 278, 4, 54, "Subsection",ExpressionUUID->"0d3bdf72-4a6f-40d6-818c-2af93e9f5e38"],
Cell[CellGroupData[{
Cell[10945, 292, 1077, 25, 110, "Input",ExpressionUUID->"a2ff33b0-bf45-4a4d-8db4-06109cda43c8"],
Cell[CellGroupData[{
Cell[12047, 321, 457, 11, 24, "Print",ExpressionUUID->"a57868f2-0469-4c56-bff5-b996bf49deed"],
Cell[12507, 334, 472, 12, 24, "Print",ExpressionUUID->"a9098e5b-22d2-42ad-90df-473486bb4951"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13040, 353, 188, 3, 54, "Subsection",ExpressionUUID->"e1b7db39-2fab-482c-a2ff-71edb0439947"],
Cell[13231, 358, 747, 17, 88, "Input",ExpressionUUID->"21cbd1bd-fdc8-44ed-aff7-25084835dd53"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14015, 380, 468, 8, 54, "Subsection",ExpressionUUID->"c2ffdcb2-95b1-498e-8b0d-efa40dd5fd64"],
Cell[14486, 390, 152, 3, 30, "Input",ExpressionUUID->"f61df6af-e350-4c16-87ba-da5934f8ac4d"],
Cell[14641, 395, 4454, 127, 223, "Input",ExpressionUUID->"e91fc9b1-1761-41df-bfc3-46afda2d0946"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19132, 527, 242, 4, 54, "Subsection",ExpressionUUID->"29f276de-42ab-46b2-90fe-29c6700d19bf"],
Cell[CellGroupData[{
Cell[19399, 535, 229, 4, 45, "Subsubsection",ExpressionUUID->"fce51adf-2f19-449f-9e95-308944874dfd"],
Cell[19631, 541, 4219, 120, 357, "Input",ExpressionUUID->"39e39a0f-dfc5-4ac8-865f-f2aa148af39f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23887, 666, 342, 7, 45, "Subsubsection",ExpressionUUID->"9b2f487c-b634-44fd-8a46-40c7fca3bcf3"],
Cell[24232, 675, 5590, 142, 429, "Input",ExpressionUUID->"8deaee41-52a0-4472-9593-9a2b55f0d1e6"],
Cell[29825, 819, 1450, 21, 30, "Input",ExpressionUUID->"2acd89b0-9239-488e-84fa-2cdc634d7ee7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31312, 845, 342, 7, 45, "Subsubsection",ExpressionUUID->"cf767cf6-be0c-4356-a813-7018387e6a13"],
Cell[31657, 854, 5395, 136, 429, "Input",ExpressionUUID->"c8351bec-69c1-4783-8abc-c0bbee8020d7"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[37101, 996, 265, 4, 54, "Subsection",ExpressionUUID->"091822a1-6d63-4064-bb46-44b40086f760"],
Cell[37369, 1002, 196, 3, 35, "Text",ExpressionUUID->"7b993d05-0e53-4f55-a293-75e56a6c727b"],
Cell[37568, 1007, 4630, 129, 168, "Input",ExpressionUUID->"778ccddb-a509-4220-a5e3-ffb3f1919842"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42235, 1141, 508, 15, 54, "Subsection",ExpressionUUID->"c2754193-d0de-4116-a9c4-23a408efa830"],
Cell[42746, 1158, 1997, 52, 68, "Input",ExpressionUUID->"501ba51f-f719-49ba-a75f-a809d6dfce2e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44780, 1215, 1137, 29, 70, "Section",ExpressionUUID->"cfbb30ea-c9f0-4bc9-8e14-33a7988fb5f2"],
Cell[CellGroupData[{
Cell[45942, 1248, 165, 3, 54, "Subsection",ExpressionUUID->"2b7ca307-c304-4c7f-a79d-04dc30cc059e"],
Cell[46110, 1253, 2341, 56, 117, "Input",ExpressionUUID->"cc3cb73b-f067-4586-a692-4766c7bbfc98"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48488, 1314, 163, 3, 54, "Subsection",ExpressionUUID->"188a8542-e1c1-4202-8ee4-239167a66ccb"],
Cell[48654, 1319, 2481, 58, 117, "Input",ExpressionUUID->"f13ee2be-5846-4670-9212-93b1d04aad9b"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[51196, 1384, 261, 4, 58, "Chapter",ExpressionUUID->"a5ed659d-71ac-4923-979e-4157241debd6"],
Cell[CellGroupData[{
Cell[51482, 1392, 706, 18, 69, "Section",ExpressionUUID->"404ca317-e7d4-44fa-8ebe-8c4020f603fc"],
Cell[CellGroupData[{
Cell[52213, 1414, 170, 3, 54, "Subsection",ExpressionUUID->"fe7f9b4c-5be5-4bb0-a76f-f9fb17aa69e1"],
Cell[CellGroupData[{
Cell[52408, 1421, 2604, 68, 231, "Input",ExpressionUUID->"9b46ec8f-731e-433e-9e25-5183d8ecffa2"],
Cell[CellGroupData[{
Cell[55037, 1493, 365, 9, 24, "Print",ExpressionUUID->"a03a9c0e-c3d9-4b48-8952-9f9bd4a57e1d"],
Cell[55405, 1504, 364, 9, 24, "Print",ExpressionUUID->"f6b8dddd-358b-4639-b626-c3b701e691de"],
Cell[55772, 1515, 335, 8, 24, "Print",ExpressionUUID->"d172fbb1-0f4b-4dfd-ad55-3a0a12b4346e"],
Cell[56110, 1525, 352, 9, 24, "Print",ExpressionUUID->"cf3dbfe0-3d93-4e9b-aa8f-c2299229f347"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[56511, 1540, 6528, 111, 97, "Input",ExpressionUUID->"45ad9c34-d6e3-4b41-9d5c-3250f1f5a0d4"],
Cell[63042, 1653, 1295, 23, 26, "Print",ExpressionUUID->"7888b505-c7fe-4e31-80b6-ed9b7cc64d90"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[64386, 1682, 231, 4, 54, "Subsection",ExpressionUUID->"0c6f9512-4271-4b02-af8b-2e1fa4045d2e"],
Cell[CellGroupData[{
Cell[64642, 1690, 1602, 39, 72, "Input",ExpressionUUID->"544d3810-dce0-44f5-ac36-4787406b9f70"],
Cell[66247, 1731, 1262, 22, 26, "Print",ExpressionUUID->"d0c2e50f-56eb-48ba-9654-b8c228744d52"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[67570, 1760, 183, 3, 67, "Section",ExpressionUUID->"67fad244-d548-4dbc-831e-d07e7f0dcfe4"],
Cell[67756, 1765, 4733, 99, 149, "Input",ExpressionUUID->"83ac2475-a52f-4abd-a9c0-2c25ce904530"],
Cell[CellGroupData[{
Cell[72514, 1868, 2834, 61, 131, "Input",ExpressionUUID->"2d64c341-6ce9-4f9e-bdfd-ed1eb6fc11d3"],
Cell[75351, 1931, 94817, 1699, 339, "Output",ExpressionUUID->"1447291a-460a-43f2-a6d1-6d4bee33df1c"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

